#
# spec file for package golang-github-prometheus-prometheus
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2017 Silvio Moioli <moio@suse.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Compatibility with systems older than Nov 2017
# See https://en.opensuse.org/openSUSE:Packaging_Conventions_RPM_Macros
%if ! %{defined _fillupdir}
%define _fillupdir /var/adm/fillup-templates
%endif
%if 0%{?suse_version} < 1500
%define _sharedstatedir /var/lib
%endif

Name:           golang-github-prometheus-prometheus
Version:        2.53.4
Release:        150100.4.26.2
Summary:        The Prometheus monitoring system and time series database
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://prometheus.io/
# also includes web assets generated with `make assets`
Source:         prometheus-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        web-ui-%{version}.tar.gz
Source3:        prometheus.service
Source4:        prometheus.yml
Source5:        prometheus.sysconfig
Source6:        prometheus.firewall.xml
Source7:        npm_licenses.tar.bz2
Source8:        Makefile
Source9:        PACKAGING_README.md
Patch1:         0001-Do-not-force-the-pure-Go-name-resolver.patch
# Lifted from Debian's prometheus package
Patch2:         0002-Default-settings.patch
# https://github.com/prometheus/prometheus/pull/14373
Patch3:         0003-Bump-go-retryablehttp.patch
# https://github.com/prometheus/prometheus/pull/16520
Patch4:         0004-Bump-go-net.patch
BuildRequires:  fdupes
%if 0%{?suse_version} == 1500 && 0%{?sle_version} < 150300
BuildRequires:  firewall-macros
%endif
# Adding glibc-devel-static seems to be required for linking if building
# with -buildmode=pie
BuildRequires:  glibc-devel-static
BuildRequires:  golang-github-prometheus-promu >= 0.14.0
BuildRequires:  golang(API) >= 1.23
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1500
Recommends:     firewalld-prometheus-config
%endif
Requires(pre):  user(prometheus)
Requires(pre):  group(prometheus)
Requires(post): %fillup_prereq
Provides:       prometheus = %{version}
ExcludeArch:    s390
%systemd_ordering

%description
Prometheus's main features are:
 - a multi-dimensional data model (time series identified by metric name and key/value pairs)
 - a flexible query language to leverage this dimensionality
 - no reliance on distributed storage; single server nodes are autonomous
 - time series collection happens via a pull model over HTTP
 - pushing time series is supported via an intermediary gateway
 - targets are discovered via service discovery or static configuration
 - multiple modes of graphing and dashboarding support

%prep
%setup -q -a1 -n prometheus-%{version}
%autosetup -D -a2 -p1 -n prometheus-%{version}

%build
%ifarch i586 s390x armv7hl armv7l armv7l:armv6l:armv5tel armv6hl
export BUILD_CGO_FLAG="--cgo"
%endif
export GOFLAGS="-buildmode=pie"
promu build -v $BUILD_CGO_FLAG

%check
./prometheus --version
./promtool --version

%install
install -D -m0755 %{_builddir}/prometheus-%{version}/prometheus %{buildroot}/%{_bindir}/prometheus
install -D -m0755 %{_builddir}/prometheus-%{version}/promtool %{buildroot}/%{_bindir}/promtool
install -D -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/prometheus.service

install -D -m 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/prometheus/prometheus.yml

install -d -m 0755 %{buildroot}%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcprometheus

install -m 0755 -d %{buildroot}%{_datarootdir}/prometheus
cp -fr console_libraries/ consoles/ %{buildroot}%{_datarootdir}/prometheus

install -m 0755 -d %{buildroot}%{_fillupdir}
install -m 0644 %{SOURCE5} %{buildroot}%{_fillupdir}/sysconfig.prometheus

%if 0%{?suse_version} == 1500 && 0%{?sle_version} < 150300
install -m 0755 -d %{buildroot}%{_prefix}/lib/firewalld/services/
install -m 0644 %{SOURCE6} %{buildroot}%{_prefix}/lib/firewalld/services/prometheus.xml
%endif

install -Dd -m 0750 %{buildroot}%{_localstatedir}/lib/prometheus
install -Dd -m 0750 %{buildroot}%{_localstatedir}/lib/prometheus/data
install -Dd -m 0750 %{buildroot}%{_localstatedir}/lib/prometheus/metrics

install -D -m0644 %{SOURCE7} %{buildroot}/%{_defaultlicensedir}/%{name}/npm_licenses.tar.bz2

%fdupes %{buildroot}/%{_prefix}

%pre
%service_add_pre prometheus.service

%post
%fillup_only -n prometheus
%service_add_post prometheus.service
%if 0%{?suse_version} == 1500 && 0%{?sle_version} < 150300
%firewalld_reload
%endif

%preun
%service_del_preun prometheus.service

%postun
%service_del_postun prometheus.service

%verifyscript
%fillup_only -n prometheus

%files
%defattr(-,root,root,-)
%doc README.md
%license LICENSE
%license %{_defaultlicensedir}/%{name}
%{_bindir}/prometheus
%{_bindir}/promtool
%{_unitdir}/prometheus.service
%{_sbindir}/rcprometheus
%{_datarootdir}/prometheus
%{_fillupdir}/sysconfig.prometheus
%dir %attr(0700,prometheus,prometheus) %{_sharedstatedir}/prometheus
%dir %attr(0700,prometheus,prometheus) %{_sharedstatedir}/prometheus/data
%dir %attr(0700,prometheus,prometheus) %{_sharedstatedir}/prometheus/metrics
%dir %{_sysconfdir}/prometheus
%config(noreplace) %{_sysconfdir}/prometheus/prometheus.yml

%if 0%{?suse_version} == 1500 && 0%{?sle_version} < 150300
%package -n firewalld-prometheus-config
Summary:        Firewalld configuration file for Prometheus
Group:          Productivity/Networking/Security
Version:        0.1
Release:        150100.4.26.2
License:        GPL-2.0-or-later
Requires:       firewalld

%description -n firewalld-prometheus-config
This package contains configuration file for Prometheus for older versions of
Firewalld which do not provide this in own package.

%files -n firewalld-prometheus-config
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_prefix}/lib/firewalld/services/prometheus.xml
%endif

%changelog
* Thu May  8 2025 witold.bedyk@suse.com
- Require Go >= 1.23 for building
  (CVE-2023-45288, bsc#1236516)
- Add 0004-Bump-go-net.patch
- Bump golang.org/x/net to version 0.39.0
  (CVE-2025-22870, bsc#1238686)
- Update to 2.53.4:
  * [BUGFIX] Runtime: fix GOGC is being set to 0 when installed
    with empty prometheus.yml file resulting high cpu usage.
  * [BUGFIX] Scrape: fix dropping valid metrics after previous
    scrape failed.
* Tue Nov 26 2024 witold.bedyk@suse.com
- Build PIE
- Require Go >= 1.21 for building
- Rebase 0003-Bump-go-retryablehttp.patch
- Remove vendor.tar.gz during "make clean"
- Update to 2.53.3 (jsc#PED-11740):
  * [BUGFIX] Scraping: allow multiple samples on same series, with
    explicit timestamps.
- Update to 2.53.2:
  * [BUGFIX] Remote-Read: Resolve occasional segmentation fault on
    query.
- Update to 2.53.1:
  * [BUGFIX] Remote-write: stop dropping samples in catch-up
- Update to 2.53.0:
  This release changes the default for GOGC, the Go runtime control
  for the trade-off between excess memory use and CPU usage. We
  have found that Prometheus operates with minimal additional CPU
  usage, but greatly reduced memory by adjusting the upstream Go
  default from 100 to 75.
  * [CHANGE] Rules: Execute 1 query instead of N (where N is the
    number of alerts within alert rule) when restoring alerts.
  * [CHANGE] Runtime: Change GOGC threshold from 100 to 75
  * [FEATURE] Rules: Add new option query_offset for each rule
    group via rule group configuration file and rule_query_offset
    as part of the global configuration to have more resilience for
    remote write delays.
  * [ENHANCEMENT] Rules: Add
    rule_group_last_restore_duration_seconds metric to measure the
    time it takes to restore a rule group.
  * [ENHANCEMENT] OTLP: Improve remote write format translation
    performance by using label set hashes for metric identifiers
    instead of string based ones.
  * [ENHANCEMENT] TSDB: Optimize querying with regexp matchers.
  * [BUGFIX] OTLP: Don't generate target_info unless there are
    metrics and at least one identifying label is defined.
  * [BUGFIX] Scrape: Do no try to ingest native histograms when the
    native histograms feature is turned off. This happened when
    protobuf scrape was enabled by for example the created time
    feature.
  * [BUGFIX] Scaleway SD: Use the instance's public IP if no
    private IP is available as the __address__ meta label.
  * [BUGFIX] Query logger: Do not leak file descriptors on error.
  * [BUGFIX] TSDB: Let queries with heavy regex matches be
    cancelled and not use up the CPU.
  * [BUGFIX] API: Do not warn if result count is equal to the
    limit, only when exceeding the limit for the series,
    label-names and label-values APIs.
  * [BUGFIX] TSDB: Fix head stats and hooks when replaying a
    corrupted snapshot.
- Update to 2.52.0:
  * [CHANGE] TSDB: Fix the predicate checking for blocks which are
    beyond the retention period to include the ones right at the
    retention boundary.
  * [FEATURE] Kubernetes SD: Add a new metric
    prometheus_sd_kubernetes_failures_total to track failed
    requests to Kubernetes API.
  * [FEATURE] Kubernetes SD: Add node and zone metadata labels when
    using the endpointslice role.
  * [FEATURE] Azure SD/Remote Write: Allow usage of Azure
    authorization SDK.
  * [FEATURE] Alerting: Support native histogram templating.
  * [FEATURE] Linode SD: Support IPv6 range discovery and region
    filtering.
  * [ENHANCEMENT] PromQL: Performance improvements for queries with
    regex matchers.
  * [ENHANCEMENT] PromQL: Performance improvements when using
    aggregation operators.
  * [ENHANCEMENT] PromQL: Validate label_join destination label.
  * [ENHANCEMENT] Scrape: Increment
    prometheus_target_scrapes_sample_duplicate_timestamp_total
    metric on duplicated series during one scrape.
  * [ENHANCEMENT] TSDB: Many improvements in performance.
  * [ENHANCEMENT] TSDB: Pause regular block compactions if the head
    needs to be compacted (prioritize head as it increases memory
    consumption).
  * [ENHANCEMENT] Observability: Improved logging during signal
    handling termination.
  * [ENHANCEMENT] Observability: All log lines for drop series use
    "num_dropped" key consistently.
  * [ENHANCEMENT] Observability: Log chunk snapshot and mmaped
    chunk replay duration during WAL replay.
  * [ENHANCEMENT] Observability: Log if the block is being created
    from WBL during compaction.
  * [BUGFIX] PromQL: Fix inaccurate sample number statistic when
    querying histograms.
  * [BUGFIX] PromQL: Fix histogram_stddev and histogram_stdvar for
    cases where the histogram has negative buckets.
  * [BUGFIX] PromQL: Fix possible duplicated label name and values
    in a metric result for specific queries.
  * [BUGFIX] Scrape: Fix setting native histogram schema factor
    during scrape.
  * [BUGFIX] TSDB: Fix counting of histogram samples when creating
    WAL checkpoint stats.
  * [BUGFIX] TSDB: Fix cases of compacting empty heads.
  * [BUGFIX] TSDB: Count float histograms in WAL checkpoint.
  * [BUGFIX] Remote Read: Fix memory leak due to broken requests.
  * [BUGFIX] API: Stop building response for /api/v1/series/ when
    the API request was cancelled.
  * [BUGFIX] promtool: Fix panic on promtool tsdb analyze
  - -extended when no native histograms are present.
- Update to 2.51.2:
  * [BUGFIX] Notifier: could hang when using relabeling on alerts
- Update to 2.51.1:
  * [BUGFIX] PromQL: Re-instate validation of label_join
    destination label
  * [BUGFIX] Scraping (experimental native histograms): Fix
    handling of the min bucket factor on sync of targets
  * [BUGFIX] PromQL: Some queries could return the same series
    twice (library use only)
- Update to 2.51.0:
  * [CHANGE] Scraping: Do experimental timestamp alignment even if
    tolerance is bigger than 1%% of scrape interval
  * [FEATURE] Alerting: Relabel rules for AlertManagerConfig;
    allows routing alerts to different alertmanagers
  * [FEATURE] API: add limit param to series, label-names and
    label-values APIs
  * [FEATURE] UI (experimental native histograms): Add native
    histogram chart to Table view
  * [FEATURE] Promtool: Add a "tsdb dump-openmetrics" to dump in
    OpenMetrics format.
  * [FEATURE] PromQL (experimental native histograms): Add
    histogram_avg function
  * [ENHANCEMENT] Rules: Evaluate independent rules concurrently
  * [ENHANCEMENT] Scraping (experimental native histograms):
    Support exemplars
  * [ENHANCEMENT] Remote Write: Disable resharding during active
    retry backoffs
  * [ENHANCEMENT] Observability: Add native histograms to
    latency/duration metrics
  * [ENHANCEMENT] Observability: Add 'type' label to
    prometheus_tsdb_head_out_of_order_samples_appended_total
  * [ENHANCEMENT] API: Faster generation of targets into JSON
  * [ENHANCEMENT] Scraping, API: Use faster compression library
  * [ENHANCEMENT] OpenTelemetry: Performance improvements in OTLP
    parsing
  * [ENHANCEMENT] PromQL: Optimisations to reduce CPU and memory
  * [BUGFIX] PromQL: Constrain extrapolation in rate() to half of
    sample interval
  * [BUGFIX] PromQL: Fix wrongly scoped range vectors with @
    modifier
  * [BUGFIX] Kubernetes SD: Pod status changes were not discovered
    by Endpoints service discovery
  * [BUGFIX] Azure SD: Fix 'error: parameter
    virtualMachineScaleSetName cannot be empty'
  * [BUGFIX] Remote Write: Fix signing for AWS sigv4 transport
  * [BUGFIX] Observability: Exemplars emitted by Prometheus use
    "trace_id" not "traceID"
- Update to 2.50.1:
  * [BUGFIX] API: Fix metadata API using wrong field names.
- Update to 2.50.0:
  * [CHANGE] Remote Write: Error storage.ErrTooOldSample is now
    generating HTTP error 400 instead of HTTP error 500.
  * [FEATURE] Remote Write: Drop old inmemory samples. Activated
    using the config entry sample_age_limit.
  * [FEATURE] Experimental: Add support for ingesting zeros as
    created timestamps. (enabled under the feature-flag
    created-timestamp-zero-ingestion).
  * [FEATURE] Promtool: Add analyze histograms command.
  * [FEATURE] TSDB/compaction: Add a way to enable overlapping
    compaction.
  * [FEATURE] Add automatic memory limit handling. Activated using
    the feature flag. auto-gomemlimit
  * [ENHANCEMENT] Promtool: allow specifying multiple matchers in
    promtool tsdb dump.
  * [ENHANCEMENT] PromQL: Restore more efficient version of
    NewPossibleNonCounterInfo annotation.
  * [ENHANCEMENT] Kuma SD: Extend configuration to allow users to
    specify client ID.
  * [ENHANCEMENT] PromQL: Use natural sort in sort_by_label and
    sort_by_label_desc. This is experimental.
  * [ENHANCEMENT] Native Histograms: support
    native_histogram_min_bucket_factor in scrape_config.
  * [ENHANCEMENT] Native Histograms: Issue warning if histogramRate
    is applied to the wrong kind of histogram.
  * [ENHANCEMENT] TSDB: Make transaction isolation data structures
    smaller.
  * [ENHANCEMENT] TSDB/postings: Optimize merge using Loser Tree.
  * [ENHANCEMENT] TSDB: Simplify internal series delete function.
  * [ENHANCEMENT] Agent: Performance improvement by making the
    global hash lookup table smaller.
  * [ENHANCEMENT] PromQL: faster execution of metric functions,
    e.g. abs(), rate()
  * [ENHANCEMENT] TSDB: Optimize label values with matchers by
    taking shortcuts.
  * [ENHANCEMENT] Kubernetes SD: Check preconditions earlier and
    avoid unnecessary checks or iterations in kube_sd.
  * [ENHANCEMENT] Promtool: Improve visibility for promtool test
    rules with JSON colored formatting.
  * [ENHANCEMENT] Consoles: Exclude iowait and steal from CPU
    Utilisation.
  * [ENHANCEMENT] Various improvements and optimizations on Native
    Histograms.
  * [BUGFIX] Scraping: Fix quality value in HTTP Accept header.
  * [BUGFIX] UI: Fix usage of the function time() that was
    crashing.
  * [BUGFIX] Azure SD: Fix SD crashing when it finds a VM scale
    set.
- Update to 2.49.1:
  * [BUGFIX] TSDB: Fixed a wrong q= value in scrape accept header
- Update to 2.49.0:
  * [FEATURE] Promtool: Add --run flag promtool test rules command.
  * [FEATURE] SD: Add support for NS records to DNS SD.
  * [FEATURE] UI: Add heatmap visualization setting in the Graph
    tab, useful histograms.
  * [FEATURE] Scraping: Add scrape_config.enable_compression
    (default true) to disable gzip compression when scraping the
    target.
  * [FEATURE] PromQL: Add a promql-experimental-functions feature
    flag containing some new experimental PromQL functions.
    NOTE: More experimental functions might be added behind the
    same feature flag in the future. Added functions: experimental
    mad_over_time (median absolute deviation around the median)
    function. and experimental sort_by_label and
    sort_by_label_desc functions allowing sorting returned series
    by labels.
  * [FEATURE] SD: Add __meta_linode_gpus label to Linode SD.
  * [FEATURE] API: Add exclude_alerts query parameter to
    /api/v1/rules to only return recording rules.
  * [FEATURE] TSDB: --storage.tsdb.retention.time flag value is now
    exposed as a prometheus_tsdb_retention_limit_seconds metric.
  * [FEATURE] Scraping: Add ability to specify priority of scrape
    protocols to accept during scrape (e.g. to scrape Prometheus
    proto format for certain jobs). This can be changed by setting
    global.scrape_protocols and scrape_config.scrape_protocols.
  * [ENHANCEMENT] Scraping: Automated handling of scraping
    histograms that violate
    scrape_config.native_histogram_bucket_limit setting.
  * [ENHANCEMENT] Scraping: Optimized memory allocations when
    scraping.
  * [ENHANCEMENT] SD: Added cache for Azure SD to avoid
    rate-limits.
  * [ENHANCEMENT] TSDB: Various improvements to OOO exemplar
    scraping. E.g. allowing ingestion of exemplars with the same
    timestamp, but with different labels.
  * [ENHANCEMENT] API: Optimize /api/v1/labels and
    /api/v1/label/<label_name>/values when 1 set of matchers are
    used.
  * [ENHANCEMENT] TSDB: Various optimizations for TSDB block index,
    head mmap chunks and WAL, reducing latency and memory
    allocations (improving API calls, compaction queries etc).
  * [ENHANCEMENT] PromQL: Optimize memory allocations and latency
    when querying float histograms.
  * [ENHANCEMENT] Rules: Instrument TraceID in log lines for rule
    evaluations.
  * [ENHANCEMENT] PromQL: Optimize memory allocations in
    query_range calls.
  * [ENHANCEMENT] Promtool: unittest interval now defaults to
    evaluation_intervals when not set.
  * [BUGFIX] SD: Fixed Azure SD public IP reporting
  * [BUGFIX] API: Fix inaccuracies in posting cardinality
    statistics.
  * [BUGFIX] PromQL: Fix inaccuracies of histogram_quantile with
    classic histograms.
  * [BUGFIX] TSDB: Fix rare fails or inaccurate queries with OOO
    samples.
  * [BUGFIX] TSDB: Fix rare panics on append commit when exemplars
    are used.
  * [BUGFIX] TSDB: Fix exemplar WAL storage, so remote write can
    send/receive samples before exemplars.
  * [BUGFIX] Mixins: Fix url filter on remote write dashboards.
  * [BUGFIX] PromQL/TSDB: Various fixes to float histogram
    operations.
  * [BUGFIX] Promtool: Fix int32 overflow issues for 32-bit
    architectures.
  * [BUGFIX] SD: Fix Azure VM Scale Set NIC issue.
- Update to 2.48.1:
  * [BUGFIX] TSDB: Make the wlog watcher read segments
    synchronously when not tailing.
  * [BUGFIX] Agent: Participate in notify calls (fixes slow down in
    remote write handling introduced in 2.45).
- Update to 2.48.0:
  - [SECURITY] Update golang-jwt to version 5.0 to fix bad error
    handling (CVE-2024-51744, bsc#1232970)
  - [CHANGE] Remote-write: respect Retry-After header on 5xx
    errors.
  - [FEATURE] Alerting: Add AWS SigV4 authentication support for
    Alertmanager endpoints.
  - [FEATURE] Promtool: Add support for histograms in the TSDB dump
    command.
  - [FEATURE] PromQL: Add warnings (and annotations) to PromQL
    query results.
  - [FEATURE] Remote-write: Add Azure AD OAuth authentication
    support for remote write requests.
  - [ENHANCEMENT] Remote-write: Add a header to count retried
    remote write requests.
  - [ENHANCEMENT] TSDB: Improve query performance by re-using
    iterator when moving between series.
  - [ENHANCEMENT] UI: Move /targets page discovered labels to
    expandable section
  - [ENHANCEMENT] TSDB: Optimize WBL loading by not sending empty
    buffers over channel.
  - [ENHANCEMENT] TSDB: Reply WBL mmap markers concurrently.
  - [ENHANCEMENT] Promtool: Add support for specifying series
    matchers in the TSDB analyze command.
  - [ENHANCEMENT] PromQL: Prevent Prometheus from overallocating
    memory on subquery with large amount of steps.
  - [ENHANCEMENT] PromQL: Add warning when monotonicity is forced
    in the input to histogram_quantile.
  - [ENHANCEMENT] Scraping: Optimize sample appending by reducing
    garbage.
  - [ENHANCEMENT] Storage: Reduce memory allocations in queries
    that merge series sets.
  - [ENHANCEMENT] UI: Show group interval in rules display.
  - [ENHANCEMENT] Scraping: Save memory when scraping by delaying
    creation of buffer.
  - [ENHANCEMENT] Agent: Allow ingestion of out-of-order samples.
  - [ENHANCEMENT] Promtool: Improve support for native histograms
    in TSDB analyze command.
  - [ENHANCEMENT] Scraping: Add configuration option for tracking
    staleness of scraped timestamps.
  - [BUGFIX] SD: Ensure that discovery managers are properly
    canceled.
  - [BUGFIX] TSDB: Fix PostingsForMatchers race with creating new
    series.
  - [BUGFIX] TSDB: Fix handling of explicit counter reset header in
    histograms.
  - [BUGFIX] SD: Validate HTTP client configuration in HTTP, EC2,
    Azure, Uyuni, PuppetDB, and Lightsail SDs.
  - [BUGFIX] TSDB: Fix counter reset edgecases causing native
    histogram panics.
  - [BUGFIX] TSDB: Fix duplicate sample detection at chunk size
    limit.
  - [BUGFIX] Promtool: Fix errors not being reported in check rules
    command.
  - [BUGFIX] TSDB: Avoid panics reported in logs when head
    initialization takes a long time.
  - [BUGFIX] TSDB: Ensure that WBL is repaired when possible.
  - [BUGFIX] Storage: Fix crash caused by incorrect mixed samples
    handling.
  - [BUGFIX] TSDB: Fix compactor failures by adding min time to
    histogram chunks.
- Update to 2.47.2:
  * [BUGFIX] TSDB: Fix counter reset edgecases causing native
    histogram panics.
- Update to 2.47.1:
  * [BUGFIX] Fix duplicate sample detection at chunk size limit
- Update to 2.47.0:
  This release adds an experimental OpenTelemetry (OTLP) Ingestion
  feature, and also new setting `keep_dropped_targets` to limit the
  amount of dropped targets held in memory. This defaults to 0
  meaning 'no limit', so we encourage users with large Prometheus
  to try setting a limit such as 100.
  * [FEATURE] Web: Add OpenTelemetry (OTLP) Ingestion endpoint.
  * [FEATURE] Scraping: Optionally limit detail on dropped targets,
    to save memory.
  * [ENHANCEMENT] TSDB: Write head chunks to disk in the background
    to reduce blocking.
  * [ENHANCEMENT] PromQL: Speed up aggregate and function queries.
  * [ENHANCEMENT] PromQL: More efficient evaluation of query with
    `timestamp()`.
  * [ENHANCEMENT] API: Faster streaming of Labels to JSON.
  * [ENHANCEMENT] Agent: Memory pooling optimisation.
  * [ENHANCEMENT] TSDB: Prevent storage space leaks due to
    terminated snapshots on shutdown.
  * [ENHANCEMENT] Histograms: Refactoring and optimisations.
  * [ENHANCEMENT] Histograms: Add `histogram_stdvar` and
    `histogram_stddev` functions.
  * [ENHANCEMENT] Remote-write: add http.resend_count tracing
    attribute.
  * [ENHANCEMENT] TSDB: Support native histograms in snapshot on
    shutdown.
  * [BUGFIX] TSDB/Agent: ensure that new series get written to WAL
    on rollback.
  * [BUGFIX] Scraping: fix infinite loop on exemplar in protobuf
    format.
- Update to 2.46.0:
  * [FEATURE] Promtool: Add PromQL format and label matcher
    set/delete commands to promtool.
  * [FEATURE] Promtool: Add push metrics command.
  * [ENHANCEMENT] Promtool: Read from stdin if no filenames are
    provided in check rules.
  * [ENHANCEMENT] Hetzner SD: Support larger ID's that will be used
    by Hetzner in September.
  * [ENHANCEMENT] Kubernetes SD: Add more labels for endpointslice
    and endpoints role.
  * [ENHANCEMENT] Kubernetes SD: Do not add pods to target group if
    the PodIP status is not set.
  * [ENHANCEMENT] OpenStack SD: Include instance image ID in
    labels.
  * [ENHANCEMENT] Remote Write receiver: Validate the metric names
    and labels.
  * [BUGFIX] Histograms: Fix parsing of float histograms without
    zero bucket.
  * [BUGFIX] Histograms: Fix scraping native and classic histograms
    missing some histograms.
  * [BUGFIX] Histograms: Enable ingestion of multiple exemplars per
    sample.
  * [BUGFIX] PromQL Engine: Include query parsing in active-query
    tracking.
  * [BUGFIX] TSDB: Handle TOC parsing failures.
* Mon Jul 22 2024 witold.bedyk@suse.com
- Require Go > 1.20 for building
* Wed Jul  3 2024 witold.bedyk@suse.com
- Bump go-retryablehttp to version 0.7.7
  (CVE-2024-6104, bsc#1227038)
- Migrate from `disabled` to `manual` service mode
- Add0003-Bump-go-retryablehttp.patch
- Update to 2.45.6 (jsc#PED-3577):
  * Security fixes in dependencies
- Update to 2.45.5:
  * [BUGFIX] tsdb/agent: ensure that new series get written to WAL
    on rollback.
  * [BUGFIX] Remote write: Avoid a race condition when applying
    configuration.
- Update to 2.45.4:
  * [BUGFIX] Remote read: Release querier resources before encoding
    the results.
- Update to 2.45.3:
  * Security fixes in dependencies
  * [BUGFIX] TSDB: Remove double memory snapshot on shutdown.
- Update to 2.45.2:
  * Security fixes in dependencies
  * [SECURITY] Updated otelhttp to version 0.46.1
    (CVE-2023-45142, bsc#1228556)
  * [BUGFIX] TSDB: Fix PostingsForMatchers race with creating new
    series.
- Update to 2.45.1:
  * [ENHANCEMENT] Hetzner SD: Support larger ID's that will be used
    by Hetzner in September.
  * [BUGFIX] Linode SD: Cast InstanceSpec values to int64 to avoid
    overflows on 386 architecture.
  * [BUGFIX] TSDB: Handle TOC parsing failures.
* Fri Jul 21 2023 witold.bedyk@suse.com
- update to 2.45.0 (jsc#PED-5406):
  * [FEATURE] API: New limit parameter to limit the number of items
    returned by `/api/v1/status/tsdb` endpoint.
  * [FEATURE] Config: Add limits to global config.
  * [FEATURE] Consul SD: Added support for `path_prefix`.
  * [FEATURE] Native histograms: Add option to scrape both classic
    and native histograms.
  * [FEATURE] Native histograms: Added support for two more
    arithmetic operators `avg_over_time` and `sum_over_time`.
  * [FEATURE] Promtool: When providing the block id, only one block
    will be loaded and analyzed.
  * [FEATURE] Remote-write: New Azure ad configuration to support
    remote writing directly to Azure Monitor workspace.
  * [FEATURE] TSDB: Samples per chunk are now configurable with
    flag `storage.tsdb.samples-per-chunk`. By default set to its
    former value 120.
  * [ENHANCEMENT] Native histograms: bucket size can now be limited
    to avoid scrape fails.
  * [ENHANCEMENT] TSDB: Dropped series are now deleted from the WAL
    sooner.
  * [BUGFIX] Native histograms: ChunkSeries iterator now checks if
    a new sample can be appended to the open chunk.
  * [BUGFIX] Native histograms: Fix Histogram Appender
    `Appendable()` segfault.
  * [BUGFIX] Native histograms: Fix setting reset header to gauge
    histograms in seriesToChunkEncoder.
  * [BUGFIX] TSDB: Tombstone intervals are not modified after Get()
    call.
  * [BUGFIX] TSDB: Use path/filepath to set the WAL directory.
- update to 2.44.0:
  * [FEATURE] Remote-read: Handle native histograms.
  * [FEATURE] Promtool: Health and readiness check of prometheus
    server in CLI.
  * [FEATURE] PromQL: Add `query_samples_total` metric, the total
    number of samples loaded by all queries.
  * [ENHANCEMENT] Storage: Optimise buffer used to iterate through
    samples.
  * [ENHANCEMENT] Scrape: Reduce memory allocations on target
    labels.
  * [ENHANCEMENT] PromQL: Use faster heap method for `topk()` /
    `bottomk()`.
  * [ENHANCEMENT] Rules API: Allow filtering by rule name.
  * [ENHANCEMENT] Native Histograms: Various fixes and
    improvements.
  * [ENHANCEMENT] UI: Search of scraping pools is now
    case-insensitive.
  * [ENHANCEMENT] TSDB: Add an affirmative log message for
    successful WAL repair.
  * [BUGFIX] TSDB: Block compaction failed when shutting down.
  * [BUGFIX] TSDB: Out-of-order chunks could be ignored if the
    write-behind log was deleted.
- rebase patch 0001-Do-not-force-the-pure-Go-name-resolver.patch
  onto v2.44.0
- update to 2.43.1
  * [BUGFIX] Labels: Set() after Del() would be ignored, which
    broke some relabeling rules.
- update to 2.43.0:
  * [FEATURE] Promtool: Add HTTP client configuration to query
    commands.
  * [FEATURE] Scrape: Add `include_scrape_configs` to include
    scrape configs from different files.
  * [FEATURE] HTTP client: Add `no_proxy` to exclude URLs from
    proxied requests.
  * [FEATURE] HTTP client: Add `proxy_from_enviroment` to read
    proxies from env variables.
  * [ENHANCEMENT] API: Add support for setting lookback delta per
    query via the API.
  * [ENHANCEMENT] API: Change HTTP status code from 503/422 to 499
    if a request is canceled.
  * [ENHANCEMENT] Scrape: Allow exemplars for all metric types.
  * [ENHANCEMENT] TSDB: Add metrics for head chunks and WAL folders
    size.
  * [ENHANCEMENT] TSDB: Automatically remove incorrect snapshot
    with index that is ahead of WAL.
  * [ENHANCEMENT] TSDB: Improve Prometheus parser error outputs to
    be more comprehensible.
  * [ENHANCEMENT] UI: Scope `group by` labels to metric in
    autocompletion.
  * [BUGFIX] Scrape: Fix
    `prometheus_target_scrape_pool_target_limit` metric not set
    before reloading.
  * [BUGFIX] TSDB: Correctly update
    `prometheus_tsdb_head_chunks_removed_total` and
    `prometheus_tsdb_head_chunks` metrics when reading WAL.
  * [BUGFIX] TSDB: Use the correct unit (seconds) when recording
    out-of-order append deltas in the
    `prometheus_tsdb_sample_ooo_delta` metric.
- update to 2.42.0:
  This release comes with a bunch of feature coverage for native
  histograms and breaking changes.
  If you are trying native histograms already, we recommend you
  remove the `wal` directory when upgrading.
  Because the old WAL record for native histograms is not
  backward compatible in v2.42.0, this will lead to some data
  loss for the latest data.
  Additionally, if you scrape "float histograms" or use recording
  rules on native histograms in v2.42.0 (which writes float
  histograms), it is a one-way street since older versions do not
  support float histograms.
  * [CHANGE] **breaking** TSDB: Changed WAL record format for the
    experimental native histograms.
  * [FEATURE] Add 'keep_firing_for' field to alerting rules.
  * [FEATURE] Promtool: Add support of selecting timeseries for
    TSDB dump.
  * [ENHANCEMENT] Agent: Native histogram support.
  * [ENHANCEMENT] Rules: Support native histograms in recording
    rules.
  * [ENHANCEMENT] SD: Add container ID as a meta label for pod
    targets for Kubernetes.
  * [ENHANCEMENT] SD: Add VM size label to azure service
    discovery.
  * [ENHANCEMENT] Support native histograms in federation.
  * [ENHANCEMENT] TSDB: Add gauge histogram support.
  * [ENHANCEMENT] TSDB/Scrape: Support FloatHistogram that
    represents buckets as float64 values.
  * [ENHANCEMENT] UI: Show individual scrape pools on /targets
    page.
- update to 2.41.0:
  * [FEATURE] Relabeling: Add keepequal and dropequal relabel
    actions.
  * [FEATURE] Add support for HTTP proxy headers.
  * [ENHANCEMENT] Reload private certificates when changed on disk.
  * [ENHANCEMENT] Add max_version to specify maximum TLS version in
    tls_config.
  * [ENHANCEMENT] Add goos and goarch labels to
    prometheus_build_info.
  * [ENHANCEMENT] SD: Add proxy support for EC2 and LightSail SDs.
  * [ENHANCEMENT] SD: Add new metric
    prometheus_sd_file_watcher_errors_total.
  * [ENHANCEMENT] Remote Read: Use a pool to speed up marshalling.
  * [ENHANCEMENT] TSDB: Improve handling of tombstoned chunks in
    iterators.
  * [ENHANCEMENT] TSDB: Optimize postings offset table reading.
  * [BUGFIX] Scrape: Validate the metric name, label names, and
    label values after relabeling.
  * [BUGFIX] Remote Write receiver and rule manager: Fix error
    handling.
- update to 2.40.7:
  * [BUGFIX] TSDB: Fix queries involving negative buckets of native
    histograms.
- update to 2.40.5:
  * [BUGFIX] TSDB: Fix queries involving native histograms due to
    improper reset of iterators.
- update to 2.40.3:
  * [BUGFIX] TSDB: Fix compaction after a deletion is called.
- update to 2.40.2:
  * [BUGFIX] UI: Fix black-on-black metric name color in dark mode.
- update to 2.40.1:
  * [BUGFIX] TSDB: Fix alignment for atomic int64 for 32 bit
    architecture.
  * [BUGFIX] Scrape: Fix accept headers.
- update to 2.40.0:
  * [FEATURE] Add experimental support for native histograms.
    Enable with the flag --enable-feature=native-histograms.
  * [FEATURE] SD: Add service discovery for OVHcloud.
  * [ENHANCEMENT] Kubernetes SD: Use protobuf encoding.
  * [ENHANCEMENT] TSDB: Use golang.org/x/exp/slices for improved
    sorting speed.
  * [ENHANCEMENT] Consul SD: Add enterprise admin partitions. Adds
    __meta_consul_partition label. Adds partition config in
    consul_sd_config.
  * [BUGFIX] API: Fix API error codes for /api/v1/labels and
    /api/v1/series.
- update to 2.39.1:
  * [BUGFIX] Rules: Fix notifier relabel changing the labels on
    active alerts.
- update to 2.39.0:
  * [FEATURE] experimental TSDB: Add support for ingesting
    out-of-order samples. This is configured via
    out_of_order_time_window field in the config file; check config
    file docs for more info.
  * [ENHANCEMENT] API: /-/healthy and /-/ready API calls now also
    respond to a HEAD request on top of existing GET support.
  * [ENHANCEMENT] PuppetDB SD: Add __meta_puppetdb_query label.
  * [ENHANCEMENT] AWS EC2 SD: Add __meta_ec2_region label.
  * [ENHANCEMENT] AWS Lightsail SD: Add __meta_lightsail_region
    label.
  * [ENHANCEMENT] Scrape: Optimise relabeling by re-using memory.
  * [ENHANCEMENT] TSDB: Improve WAL replay timings.
  * [ENHANCEMENT] TSDB: Optimise memory by not storing unnecessary
    data in the memory.
  * [ENHANCEMENT] TSDB: Allow overlapping blocks by default.
  - -storage.tsdb.allow-overlapping-blocks now has no effect.
  * [ENHANCEMENT] UI: Click to copy label-value pair from query
    result to clipboard.
  * [BUGFIX] TSDB: Turn off isolation for Head compaction to fix a
    memory leak.
  * [BUGFIX] TSDB: Fix 'invalid magic number 0' error on Prometheus
    startup.
  * [BUGFIX] PromQL: Properly close file descriptor when logging
    unfinished queries.
  * [BUGFIX] Agent: Fix validation of flag options and prevent WAL
    from growing more than desired.
- update to 2.38.0:
  * [FEATURE]: Web: Add a /api/v1/format_query HTTP API endpoint
    that allows pretty-formatting PromQL expressions.
  * [FEATURE]: UI: Add support for formatting PromQL expressions in
    the UI.
  * [FEATURE]: DNS SD: Support MX records for discovering targets.
  * [FEATURE]: Templates: Add toTime() template function that
    allows converting sample timestamps to Go time.Time values.
  * [ENHANCEMENT]: Kubernetes SD: Add
    __meta_kubernetes_service_port_number meta label indicating the
    service port number.
  * [ENHANCEMENT]: Kubernetes SD: Add
    __meta_kubernetes_pod_container_image meta label indicating the
    container image.
  * [ENHANCEMENT]: PromQL: When a query panics, also log the query
    itself alongside the panic message.
  * [ENHANCEMENT]: UI: Tweak colors in the dark theme to improve
    the contrast ratio.
  * [ENHANCEMENT]: Web: Speed up calls to /api/v1/rules by avoiding
    locks and using atomic types instead.
  * [ENHANCEMENT]: Scrape: Add a no-default-scrape-port feature
    flag, which omits or removes any default HTTP (:80) or HTTPS
    (:443) ports in the target's scrape address.
  * [BUGFIX]: TSDB: In the WAL watcher metrics, expose the
    type="exemplar" label instead of type="unknown" for exemplar
    records.
  * [BUGFIX]: TSDB: Fix race condition around allocating series IDs
    during chunk snapshot loading.
* Thu Apr 13 2023 kastl@b1-systems.de
- Remove npm_licenses.tar.bz2 during "make clean"
* Thu Apr  6 2023 expeehaa@outlook.com
- Remove web-ui archives during "make clean".
* Wed Apr  5 2023 witold.bedyk@suse.com
- Require promu >= 0.14.0 for building
* Fri Mar 31 2023 witold.bedyk@suse.com
- Add:
  * npm_licenses.tar.bz2
  * PACKAGING_README.md
- Drop:
  * 0003-Update-Go-modules.patch
- Change:
  * 0001-Do-not-force-the-pure-Go-name-resolver.patch
  * 0002-Default-settings.patch
- Upgrade to version 2.37.6
  * Require Go 1.19
- Upgrade to version 2.37.5
  * [SECURITY] Security upgrade from go and upstream dependencies
    that include security fixes to the net/http and os packages.
- Upgrade to version 2.37.4
  * [SECURITY] Fix basic authentication bypass vulnerability
    (CVE-2022-46146, bsc#1208049, jsc#PED-3576).
- Upgrade to version 2.37.3
  * [SECURITY] CVE-2022-41715: Limit memory used by parsing regexps
    (bsc#1204023).
  * [BUGFIX] TSDB: Turn off isolation for Head compaction to fix a
    memory leak.
- Upgrade to version 2.37.2
  * [BUGFIX] TSDB: Fix 'invalid magic number 0' error on Prometheus
    startup.
  * [BUGFIX] Agent: Fix validation of flag options and prevent WAL
    from growing more than desired.
- Upgrade to version 2.37.1
  * [BUGFIX] Properly close file descriptor when logging unfinished
    queries.
  * [BUGFIX] TSDB: In the WAL watcher metrics, expose the
    type="exemplar" label instead of type="unknown" for exemplar
    records.
- Upgrade to version 2.37.0
  * [FEATURE] Nomad SD: New service discovery for Nomad built-in
    service discovery.
  * [ENHANCEMENT] Kubernetes SD: Allow attaching node labels for
    endpoint role.
  * [ENHANCEMENT] PromQL: Optimise creation of signature
    with/without labels.
  * [ENHANCEMENT] TSDB: Memory optimizations.
  * [ENHANCEMENT] TSDB: Reduce sleep time when reading WAL.
  * [ENHANCEMENT] OAuth2: Add appropriate timeouts and User-Agent
    header.
  * [BUGFIX] Alerting: Fix Alertmanager targets not being updated
    when alerts were queued.
  * [BUGFIX] Hetzner SD: Make authentication files relative to
    Prometheus config file.
  * [BUGFIX] Promtool: Fix promtool check config not erroring
    properly on failures.
  * [BUGFIX] Scrape: Keep relabeled scrape interval and timeout on
    reloads.
  * [BUGFIX] TSDB: Don't increment
    prometheus_tsdb_compactions_failed_total when context is
    canceled.
  * [BUGFIX] TSDB: Fix panic if series is not found when deleting
    series.
  * [BUGFIX] TSDB: Increase
    prometheus_tsdb_mmap_chunk_corruptions_total on out of sequence
    errors.
  * [BUGFIX] Uyuni SD: Make authentication files relative to
    Prometheus configuration file and fix default configuration
    values.
- Upgrade to version 2.36.2
  * [BUGFIX] Fix serving of static assets like fonts and favicon.
- Upgrade to version 2.36.1
  * [BUGFIX] promtool: Add --lint-fatal option.
- Upgrade to version 2.36.0
  * [FEATURE] Add lowercase and uppercase relabel action.
  * [FEATURE] SD: Add IONOS Cloud integration.
  * [FEATURE] SD: Add Vultr integration.
  * [FEATURE] SD: Add Linode SD failure count metric.
  * [FEATURE] Add prometheus_ready metric.
  * [ENHANCEMENT] Add stripDomain to template function.
  * [ENHANCEMENT] UI: Enable active search through dropped targets.
  * [ENHANCEMENT] promtool: support matchers when querying label
    values.
  * [ENHANCEMENT] Add agent mode identifier.
  * [BUGFIX] Changing TotalQueryableSamples from int to int64.
  * [BUGFIX] tsdb/agent: Ignore duplicate exemplars.
  * [BUGFIX] TSDB: Fix chunk overflow appending samples at a
    variable rate.
  * [BUGFIX] Stop rule manager before TSDB is stopped.
- Upgrade to version 2.35.0
  * [CHANGE] TSDB: Delete *.tmp WAL files when Prometheus starts.
  * [CHANGE] promtool: Add new flag --lint (enabled by default) for
    the commands check rules and check config, resulting in a new
    exit code (3) for linter errors.
  * [FEATURE] Support for automatically setting the variable
    GOMAXPROCS to the container CPU limit. Enable with the flag
  - -enable-feature=auto-gomaxprocs.
  * [FEATURE] PromQL: Extend statistics with total and peak number
    of samples in a query. Additionally, per-step statistics are
    available with --enable-feature=promql-per-step-stats and using
    stats=all in the query API. Enable with the flag
  - -enable-feature=per-step-stats.
  * [ENHANCEMENT] TSDB: more efficient sorting of postings read from
    WAL at startup.
  * [ENHANCEMENT] Azure SD: Add metric to track Azure SD failures.
  * [ENHANCEMENT] Azure SD: Add an optional resource_group
    configuration.
  * [ENHANCEMENT] Kubernetes SD: Support discovery.k8s.io/v1
    EndpointSlice (previously only discovery.k8s.io/v1beta1
    EndpointSlice was supported).
  * [ENHANCEMENT] Kubernetes SD: Allow attaching node metadata to
    discovered pods.
  * [ENHANCEMENT] OAuth2: Support for using a proxy URL to fetch
    OAuth2 tokens.
  * [ENHANCEMENT] Configuration: Add the ability to disable HTTP2.
  * [ENHANCEMENT] Config: Support overriding minimum TLS version.
  * [BUGFIX] Kubernetes SD: Explicitly include gcp auth from k8s.io.
  * [BUGFIX] Fix OpenMetrics parser to sort uppercase labels
    correctly.
  * [BUGFIX] UI: Fix scrape interval and duration tooltip not
    showing on target page.
  * [BUGFIX] Tracing/GRPC: Set TLS credentials only when insecure is
    false.
  * [BUGFIX] Agent: Fix ID collision when loading a WAL with
    multiple segments.
  * [BUGFIX] Remote-write: Fix a deadlock between Batch and flushing
    the queue.
- Upgrade to version 2.34.0
  * [CHANGE] UI: Classic UI removed.
  * [CHANGE] Tracing: Migrate from Jaeger to OpenTelemetry based
    tracing.
  * [ENHANCEMENT] TSDB: Disable the chunk write queue by default and
    allow configuration with the experimental flag
  - -storage.tsdb.head-chunks-write-queue-size.
  * [ENHANCEMENT] HTTP SD: Add a failure counter.
  * [ENHANCEMENT] Azure SD: Set Prometheus User-Agent on requests.
  * [ENHANCEMENT] Uyuni SD: Reduce the number of logins to Uyuni.
  * [ENHANCEMENT] Scrape: Log when an invalid media type is
    encountered during a scrape.
  * [ENHANCEMENT] Scrape: Accept
    application/openmetrics-text;version=1.0.0 in addition to
    version=0.0.1.
  * [ENHANCEMENT] Remote-read: Add an option to not use external
    labels as selectors for remote read.
  * [ENHANCEMENT] UI: Optimize the alerts page and add a search bar.
  * [ENHANCEMENT] UI: Improve graph colors that were hard to see.
  * [ENHANCEMENT] Config: Allow escaping of $ with $$ when using
    environment variables with external labels.
  * [BUGFIX] PromQL: Properly return an error from
    histogram_quantile when metrics have the same labelset.
  * [BUGFIX] UI: Fix bug that sets the range input to the
    resolution.
  * [BUGFIX] TSDB: Fix a query panic when
    memory-snapshot-on-shutdown is enabled.
  * [BUGFIX] Parser: Specify type in metadata parser errors.
  * [BUGFIX] Scrape: Fix label limit changes not applying.
- Upgrade to version 2.33.5
  * [BUGFIX] Remote-write: Fix deadlock between adding to queue and
    getting batch.
- Upgrade to version 2.33.4
  * [BUGFIX] TSDB: Fix panic when m-mapping head chunks onto the
    disk.
- Upgrade to version 2.33.3
  * [BUGFIX] Azure SD: Fix a regression when public IP Address isn't
    set.
- Upgrade to version 2.33.2
  * [BUGFIX] Azure SD: Fix panic when public IP Address isn't set.
  * [BUGFIX] Remote-write: Fix deadlock when stopping a shard.
- Upgrade to version 2.33.1
  * [BUGFIX] SD: Fix no such file or directory in K8s SD when not
    running inside K8s.
- Upgrade to version 2.33.0
  * [CHANGE] PromQL: Promote negative offset and @ modifer to stable
    features.
  * [CHANGE] Web: Promote remote-write-receiver to stable.
  * [FEATURE] Config: Add stripPort template function.
  * [FEATURE] Promtool: Add cardinality analysis to check metrics,
    enabled by flag --extended.
  * [FEATURE] SD: Enable target discovery in own K8s namespace.
  * [FEATURE] SD: Add provider ID label in K8s SD.
  * [FEATURE] Web: Add limit field to the rules API.
  * [ENHANCEMENT] Remote-write: Avoid allocations by buffering
    concrete structs instead of interfaces.
  * [ENHANCEMENT] Remote-write: Log time series details for
    out-of-order samples in remote write receiver.
  * [ENHANCEMENT] Remote-write: Shard up more when backlogged.
  * [ENHANCEMENT] TSDB: Use simpler map key to improve exemplar
    ingest performance.
  * [ENHANCEMENT] TSDB: Avoid allocations when popping from the
    intersected postings heap.
  * [ENHANCEMENT] TSDB: Make chunk writing non-blocking, avoiding
    latency spikes in remote-write.
  * [ENHANCEMENT] TSDB: Improve label matching performance.
  * [ENHANCEMENT] UI: Optimize the service discovery page and add a search bar.
  * [ENHANCEMENT] UI: Optimize the target page and add a search bar.
  * [BUGFIX] Promtool: Make exit codes more consistent.
  * [BUGFIX] Promtool: Fix flakiness of rule testing.
  * [BUGFIX] Remote-write: Update
    prometheus_remote_storage_queue_highest_sent_timestamp_seconds
    metric when write irrecoverably fails.
  * [BUGFIX] Storage: Avoid panic in BufferedSeriesIterator.
  * [BUGFIX] TSDB: CompactBlockMetas should produce correct
    mint/maxt for overlapping blocks.
  * [BUGFIX] TSDB: Fix logging of exemplar storage size.
  * [BUGFIX] UI: Fix overlapping click targets for the alert state
    checkboxes.
  * [BUGFIX] UI: Fix Unhealthy filter on target page to actually
    display only Unhealthy targets.
  * [BUGFIX] UI: Fix autocompletion when expression is empty.
  * [BUGFIX] TSDB: Fix deadlock from simultaneous GC and write.
* Fri Mar 31 2023 witold.bedyk@suse.com
- Fix authentication bypass by updating Prometheus Exporter Toolkit
  to version 0.7.3 (CVE-2022-46146, bsc#1208049)
- Fix uncontrolled resource consumption by updating Go to version
  1.20.1 (CVE-2022-41723, bsc#1208298)
- Restructure the spec to build web assets online (boo#1208752)
- Add:
  * Makefile
  * web-ui-2.32.1.tar.gz
  * 0003-Update-Go-modules.patch
- Drop:
  * 0003-Bump-client_golang-to-1.12.1.patch
* Thu Apr  7 2022 jgonzalez@suse.com
- Build firewalld-prometheus-config only for SUSE Linux Enterprise
  15, 15.1 and 15.2, and require firewalld for it
- firewalld-prometheus-config needs to be a Recommends, not a
  Requires, as prometheus does not require it to run
* Fri Mar 18 2022 witold.bedyk@suse.com
- Create firewalld-prometheus-config subpackage (bsc#1197042,
  jsc#SLE-24374, jsc#SLE-24375)
* Mon Mar  7 2022 witold.bedyk@suse.com
- Update vendor tarball with prometheus/client_golang 1.12.1
  (bsc#1196338)
  * Added 0003-Bump-client_golang-to-1.12.1.patch
* Tue Feb 22 2022 witold.bedyk@suse.com
- Fix Firewalld configuration file location (bsc#1196300)
* Fri Feb 18 2022 witold.bedyk@suse.com
- Require Go 1.16+
- Do not build on s390 architecture.
* Wed Jan 19 2022 witold.bedyk@suse.com
- Updated patches:
  + Changed:
  * 0002-Default-settings.patch
  + Removed:
  * 0003-Add-Uyuni-service-discovery.patch
- Use obs-service-go_modules
- Upgrade to upstream version 2.32.1 (jsc#SLE-22863)
  + Bugfixes:
  * Scrape: Fix reporting metrics when sample limit is reached
    during the report. #9996
  * Scrape: Ensure that scrape interval and scrape timeout are
    always set. #10023
  * TSDB: Expose and fix bug in iterators' Seek() method. #10030
- Upgrade to upstream version 2.32.0
  + Change:
  * remote-write: Change default max retry time from 100ms to
    5 seconds. #9634
  + Features:
  * Agent: New mode of operation optimized for remote-write only
    scenarios, without local storage.
  * Promtool: Add promtool check service-discovery command. #8970
  + Enhancements:
  * Promtool: Improve test output. #8064
  * Promtool: Use kahan summation for better numerical stability.
  * Remote-write: Reuse memory for marshalling. #9412
  * Scrape: Add scrape_body_size_bytes scrape metric behind the
  - -enable-feature=extra-scrape-metrics flag. #9569
  * TSDB: Add windows arm64 support. #9703
  * TSDB: Optimize query by skipping unneeded sorting in TSDB.
  * Templates: Support int and uint as datatypes for template
    formatting. #9680
  * UI: Prefer rate over rad, delta over deg, and count over cos
    in autocomplete. #9688
  + Bugfixes:
  * TSDB: Add more size checks when writing individual sections
    in the index. #9710
  * PromQL: Make deriv() return zero values for constant series.
  * TSDB: Fix panic when checkpoint directory is empty. #9687
  * TSDB: Fix panic, out of order chunks, and race warning during
    WAL replay. #9856
  * UI: Correctly render links for targets with IPv6 addresses
    that contain a Zone ID. #9853
  * Promtool: Fix checking of authorization.credentials_file and
    bearer_token_file fields. #9883
  * Uyuni SD: Fix null pointer exception during initialization.
  * TSDB: Fix queries after a failed snapshot replay. #9980
- Upgrade to upstream version 2.31.1
  + Bugfix:
  * SD: Fix a panic when the experimental discovery manager
    receives targets during a reload. #9656
- Upgrade to upstream version 2.31.0
  + Change:
  * UI: Remove standard PromQL editor in favour of the
    codemirror-based editor. #9452
  + Features:
  * PromQL: Add trigonometric functions and atan2 binary
    operator. #9239 #9248 #9515
  * Remote: Add support for exemplar in the remote write receiver
    endpoint. #9319 #9414
  * SD: Add PuppetDB service discovery. #8883
  * SD: Add Uyuni service discovery. #8190
  * Web: Add support for security-related HTTP headers. #9546
  + Enhancements:
  * Azure SD: Add proxy_url, follow_redirects, tls_config. #9267
  * Backfill: Add --max-block-duration in promtool
    create-blocks-from rules. #9511
  * Config: Print human-readable sizes with unit instead of raw
    numbers. #9361
  * HTTP: Re-enable HTTP/2. #9398
  * Kubernetes SD: Warn user if number of endpoints exceeds
    limit. #9467
  * OAuth2: Add TLS configuration to token requests. #9550
  * PromQL: Several optimizations. #9365 #9360 #9362 #9552
  * PromQL: Make aggregations deterministic in instant queries.
  * Rules: Add the ability to limit number of alerts or series.
  * SD: Experimental discovery manager to avoid restarts upon
    reload.
  * UI: Debounce timerange setting changes. #9359
  + Bugfixes:
  * Backfill: Apply rule labels after query labels. #9421
  * Scrape: Resolve conflicts between multiple exported label
    prefixes. #9479 #9518
  * Scrape: Restart scrape loops when __scrape_interval__ is
    changed. #9551
  * TSDB: Fix memory leak in samples deletion. #9151
  * UI: Use consistent margin-bottom for all alert kinds. #9318
- Upgrade to upstream version 2.30.3
  + Bugfixes:
  * TSDB: Fix panic on failed snapshot replay. #9438
  * TSDB: Don't fail snapshot replay with exemplar storage
    disabled when the snapshot contains exemplars. #9438
- Upgrade to upstream version 2.30.2
  + Bugfix:
  * TSDB: Don't error on overlapping m-mapped chunks during WAL
    replay. #9381
- Upgrade to upstream version 2.30.1
  + Enhancements:
  * Remote Write: Redact remote write URL when used for metric
    label. #9383
  * UI: Redact remote write URL and proxy URL passwords in the
    /config page. #9408
  + Bugfixes:
  * promtool rules backfill: Prevent creation of data before the
    start time. #9339
  * promtool rules backfill: Do not query after the end time.
  * Azure SD: Fix panic when no computername is set. #9387
- Upgrade to upstream version 2.30.0
  + Features:
  * experimental TSDB: Snapshot in-memory chunks on shutdown for
    faster restarts. #7229
  * experimental Scrape: Configure scrape interval and scrape
    timeout via relabeling using __scrape_interval__ and
    __scrape_timeout__ labels respectively. #8911
  * Scrape: Add scrape_timeout_seconds and scrape_sample_limit
    metric. #9247 #9295
  + Enhancements:
  * Scrape: Add --scrape.timestamp-tolerance flag to adjust
    scrape timestamp tolerance when enabled via
  - -scrape.adjust-timestamps. #9283
  * Remote Write: Improve throughput when sending exemplars.
  * TSDB: Optimise WAL loading by removing extra map and caching
    min-time #9160
  * promtool: Speed up checking for duplicate rules. #9262/#9306
  * Scrape: Reduce allocations when parsing the metrics. #9299
  * docker_sd: Support host network mode #9125
  + Bugfixes:
  * Exemplars: Fix panic when resizing exemplar storage from 0 to
    a non-zero size. #9286
  * TSDB: Correctly decrement
    prometheus_tsdb_head_active_appenders when the append has no
    samples. #9230
  * promtool rules backfill: Return 1 if backfill was
    unsuccessful. #9303
  * promtool rules backfill: Avoid creation of overlapping
    blocks. #9324
  * config: Fix a panic when reloading configuration with a null
    relabel action. #9224
- Upgrade to upstream version 2.29.2
  + Bugfixes:
  * Fix Kubernetes SD failing to discover Ingress in
    Kubernetes v1.22. #9205
  * Fix data race in loading write-ahead-log (WAL). #9259
- Upgrade to upstream version 2.29.1
  + Bugfixes:
  * TSDB: align atomically accessed int64 to prevent panic in
    32-bit archs. #9192
- Upgrade to upstream version 2.29.0
  + Changes:
  * Promote --storage.tsdb.allow-overlapping-blocks flag to
    stable. #9117
  * Promote --storage.tsdb.retention.size flag to stable. #9004
  + Features:
  * Add Kuma service discovery. #8844
  * Add present_over_time PromQL function. #9097
  * Allow configuring exemplar storage via file and make it
    reloadable. #8974
  * UI: Allow selecting time range with mouse drag. #8977
  * promtool: Add feature flags flag --enable-feature. #8958
  * promtool: Add file_sd file validation. #8950
  + Enhancements:
  * Reduce blocking of outgoing remote write requests from series
    garbage collection. #9109
  * Improve write-ahead-log decoding performance. #9106
  * Improve append performance in TSDB by reducing mutexes usage.
  * Allow configuring max_samples_per_send for remote write
    metadata. #8959
  * Add __meta_gce_interface_ipv4_<name> meta label to GCE
    discovery. #8978
  * Add __meta_ec2_availability_zone_id meta label to EC2
    discovery. #8896
  * Add __meta_azure_machine_computer_name meta label to Azure
    discovery. #9112
  * Add __meta_hetzner_hcloud_labelpresent_<labelname> meta label
    to Hetzner discovery. #9028
  * promtool: Add compaction efficiency to promtool tsdb analyze
    reports. #8940
  * promtool: Allow configuring max block duration for
    backfilling via --max-block-duration flag. #8919
  * UI: Add sorting and filtering to flags page. #8988
  * UI: Improve alerts page rendering performance. #9005
  + Bugfixes:
  * Log when total symbol size exceeds 2^32 bytes, causing
    compaction to fail, and skip compaction. #9104
  * Fix incorrect target_limit reloading of zero value. #9120
  * Fix head GC and pending readers race condition. #9081
  * Fix timestamp handling in OpenMetrics parser. #9008
  * Fix potential duplicate metrics in /federate endpoint when
    specifying multiple matchers. #8885
  * Fix server configuration and validation for authentication
    via client cert. #9123
  * Allow start and end again as label names in PromQL queries.
    They were disallowed since the introduction of @ timestamp
    feature. #9119
- Upgrade to upstream version 2.28.1
  + Bugfixes:
  * HTTP SD: Allow charset specification in Content-Type header.
  * HTTP SD: Fix handling of disappeared target groups. #9019
  * Fix incorrect log-level handling after moving to go-kit/log.
- Upgrade to upstream version 2.28.0
  + Change:
  * UI: Make the new experimental PromQL editor the default.
  + Features:
  * Linode SD: Add Linode service discovery. #8846
  * HTTP SD: Add generic HTTP-based service discovery. #8839
  * Kubernetes SD: Allow configuring API Server access via a
    kubeconfig file. #8811
  * UI: Add exemplar display support to the graphing interface.
  * Consul SD: Add namespace support for Consul Enterprise. #8900
  + Enhancements:
  * Promtool: Allow silencing output when importing / backfilling
    data. #8917
  * Consul SD: Support reading tokens from file. #8926
  * Rules: Add a new .ExternalURL alert field templating
    variable, containing the external URL of the Prometheus
    server. #8878
  * Scrape: Add experimental body_size_limit scrape configuration
    setting to limit the allowed response body size for target
    scrapes. #8833 #8886
  * Kubernetes SD: Add ingress class name label for ingress
    discovery. #8916
  * UI: Show a startup screen with progress bar when the TSDB is
    not ready yet. #8662 #8908 #8909 #8946
  * SD: Add a target creation failure counter
    prometheus_target_sync_failed_total and improve target
    creation failure handling. #8786
  * TSDB: Improve validation of exemplar label set length. #8816
  * TSDB: Add a prometheus_tsdb_clean_start metric that indicates
    whether a TSDB lockfile from a previous run still existed
    upon startup. #8824
  + Bugfixes:
  * UI: In the experimental PromQL editor, fix autocompletion and
    parsing for special float values and improve series metadata
    fetching. #8856
  * TSDB: When merging chunks, split resulting chunks if they
    would contain more than the maximum of 120 samples. #8582
  * SD: Fix the computation of the
    prometheus_sd_discovered_targets metric when using multiple
    service discoveries. #8828
* Mon Sep 20 2021 jsegitz@suse.com
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * prometheus.service
* Thu Jul  8 2021 witold.bedyk@suse.com
- Provide and reload firewalld configuration only for:
  + openSUSE Leap 15.0, 15.1, 15.2
  + SUSE SLE15, SLE15 SP1, SLE15 SP2
* Wed May 19 2021 daniel.molkentin@suse.com
- Refresh patches
  + Changed:
  * 0001-Do-not-force-the-pure-Go-name-resolver.patch
  * 0002-Default-settings.patch
  * 0003-Add-Uyuni-service-discovery.patch
- Upgrade to upstream version 2.27.1 (jsc#SLE-18254)
  + Bugfix:
  * SECURITY: Fix arbitrary redirects under the /new endpoint (CVE-2021-29622, bsc#1186242)
- Upgrade to upstream version 2.27.0
  + Features:
  * Promtool: Retroactive rule evaluation functionality. #7675
  * Configuration: Environment variable expansion for external labels. Behind --enable-feature=expand-external-labels flag. #8649
  * TSDB: Add a flag(--storage.tsdb.max-block-chunk-segment-size) to control the max chunks file size of the blocks for small Prometheus instances. #8478
  * UI: Add a dark theme. #8604
  * AWS Lightsail Discovery: Add AWS Lightsail Discovery. #8693
  * Docker Discovery: Add Docker Service Discovery. #8629
  * OAuth: Allow OAuth 2.0 to be used anywhere an HTTP client is used. #8761
  * Remote Write: Send exemplars via remote write. Experimental and disabled by default. #8296
  + Enhancements:
  * Digital Ocean Discovery: Add __meta_digitalocean_vpc label. #8642
  * Scaleway Discovery: Read Scaleway secret from a file. #8643
  * Scrape: Add configurable limits for label size and count. #8777
  * UI: Add 16w and 26w time range steps. #8656
  * Templating: Enable parsing strings in humanize functions. #8682
  + Bugfixes:
  * UI: Provide errors instead of blank page on TSDB Status Page. #8654 #8659
  * TSDB: Do not panic when writing very large records to the WAL. #8790
  * TSDB: Avoid panic when mmaped memory is referenced after the file is closed. #8723
  * Scaleway Discovery: Fix nil pointer dereference. #8737
  * Consul Discovery: Restart no longer required after config update with no targets. #8766
* Tue May  4 2021 witold.bedyk@suse.com
- Add tarball with vendor modules and web assets
- Uyuni: Read formula data from exporters map
- Uyuni: Add support for TLS targets
  + Changed:
  * 0003-Add-Uyuni-service-discovery.patch
  * 0002-Default-settings.patch Changed
  * 0003-Add-Uyuni-service-discovery.patch
- Upgrade to upstream version 2.26.0
  + Changes
  * Alerting: Using Alertmanager v2 API by default. #8626
  * Prometheus/Promtool: Binaries are now printing help and usage to stdout instead of stderr. #8542
  + Features
  * Remote: Add support for AWS SigV4 auth method for remote_write. #8509
  * PromQL: Allow negative offsets. Behind --enable-feature=promql-negative-offset flag. #8487
  * UI: Add advanced auto-completion, syntax highlighting and linting to graph page query input. #8634
  + Enhancements
  * PromQL: Add last_over_time, sgn, clamp functions. #8457
  * Scrape: Add support for specifying type of Authorization header credentials with Bearer by default. #8512
  * Scrape: Add follow_redirects option to scrape configuration. #8546
  * Remote: Allow retries on HTTP 429 response code for remote_write. #8237 #8477
  * Remote: Allow configuring custom headers for remote_read. #8516
  * UI: Hitting Enter now triggers new query. #8581
  * UI: Better handling of long rule and names on the /rules and /targets pages. #8608 #8609
  * UI: Add collapse/expand all button on the /targets page. #8486
- Upgrade to upstream version 2.25.0
  + Features
  * Include a new `--enable-feature=` flag that enables experimental features.
  + Enhancements
  * Add optional name property to testgroup for better test failure output. #8440
  * Add warnings into React Panel on the Graph page. #8427
  * TSDB: Increase the number of buckets for the compaction duration metric. #8342
  * Remote: Allow passing along custom remote_write HTTP headers. #8416
  * Mixins: Scope grafana configuration. #8332
  * Kubernetes SD: Add endpoint labels metadata. #8273
  * UI: Expose total number of label pairs in head in TSDB stats page. #8343
  * TSDB: Reload blocks every minute, to detect new blocks and enforce retention more often. #8343
  + Bug fixes
  * API: Fix global URL when external address has no port. #8359
  * Deprecate unused flag --alertmanager.timeout. #8407
- Upgrade to upstream version 2.24.1
  + Enhancements
  * Cache basic authentication results to significantly improve performance of HTTP endpoints.
- Upgrade to upstream version 2.24.0
  + Features
  * Add TLS and basic authentication to HTTP endpoints. #8316
  * promtool: Add check web-config subcommand to check web config files. #8319
  * promtool: Add tsdb create-blocks-from openmetrics subcommand to backfill metrics data from an OpenMetrics file. #8084
  + Enhancements
  * HTTP API: Fast-fail queries with only empty matchers. #8288
  * HTTP API: Support matchers for labels API. #8301
  * promtool: Improve checking of URLs passed on the command line. #7956
  * SD: Expose IPv6 as a label in EC2 SD. #7086
  * SD: Reuse EC2 client, reducing frequency of requesting credentials. #8311
  * TSDB: Add logging when compaction takes more than the block time range. #8151
  * TSDB: Avoid unnecessary GC runs after compaction. #8276
- Upgrade to upstream version 2.23.0
  + Changes
  * UI: Make the React UI default. #8142
  * Remote write: The following metrics were removed/renamed in remote write. #6815
    > prometheus_remote_storage_succeeded_samples_total was removed and prometheus_remote_storage_samples_total was introduced for all the samples attempted to send.
    > prometheus_remote_storage_sent_bytes_total was removed and replaced with prometheus_remote_storage_samples_bytes_total and prometheus_remote_storage_metadata_bytes_total.
    > prometheus_remote_storage_failed_samples_total -> prometheus_remote_storage_samples_failed_total .
    > prometheus_remote_storage_retried_samples_total -> prometheus_remote_storage_samples_retried_total.
    > prometheus_remote_storage_dropped_samples_total -> prometheus_remote_storage_samples_dropped_total.
    > prometheus_remote_storage_pending_samples -> prometheus_remote_storage_samples_pending.
  * Remote: Do not collect non-initialized timestamp metrics. #8060
  + Enhancements
  * Remote write: Added a metric prometheus_remote_storage_max_samples_per_send for remote write. #8102
  * TSDB: Make the snapshot directory name always the same length. #8138
  * TSDB: Create a checkpoint only once at the end of all head compactions. #8067
  * TSDB: Avoid Series API from hitting the chunks. #8050
  * TSDB: Cache label name and last value when adding series during compactions making compactions faster. #8192
  * PromQL: Improved performance of Hash method making queries a bit faster. #8025
  * promtool: tsdb list now prints block sizes. #7993
  * promtool: Calculate mint and maxt per test avoiding unnecessary calculations. #8096
  * SD: Add filtering of services to Docker Swarm SD. #8074
* Tue Mar  9 2021 witold.bedyk@suse.com
- Uyuni: `hostname` label is now set to FQDN instead of IP
  + Changed:
  * 0003-Add-Uyuni-service-discovery.patch
* Mon Nov  9 2020 stefano.torresi@suse.com
- Update to upstream version 2.22.1
- Update packaging
  * Remove systemd and shadow hard requirements
  * use systemd-sysusers to configure the user in a dedicated 'system-user-prometheus' subpackage
  * add 'prometheus' package alias
* Mon Aug 31 2020 pseidensal@suse.com
- Update package with changes from `server:monitoring` bsc#1175478
  Left out removal of firewalld related configuration files as SLE-15-SP1's
  `firewalld` package does not contain prometheus configuration yet.
* Fri Jul 31 2020 witold.bedyk@suse.com
- Update 0003-Add-Uyuni-service-discovery.patch:
  + Add support for Prometheus exporters proxy
* Wed Jun  3 2020 jcavalheiro@suse.com
- Update change log and spec file
  + Modified spec file: default to golang 1.14 to avoid "have choice" build issues in OBS.
  + Rebase and update patches for version 2.18.0
  + Changed:
  * 0001-Do-not-force-the-pure-Go-name-resolver.patch
  * 0002-Default-settings.patch Changed
  * 0003-Add-Uyuni-service-discovery.patch
- Update to 2.18.0
  + Features
  * Tracing: Added experimental Jaeger support #7148
  + Changes
  * Federation: Only use local TSDB for federation (ignore remote read). #7096
  * Rules: `rule_evaluations_total` and `rule_evaluation_failures_total` have a `rule_group` label now. #7094
  + Enhancements
  * TSDB: Significantly reduce WAL size kept around after a block cut. #7098
  * Discovery: Add `architecture` meta label for EC2. #7000
  + Bug fixes
  * UI: Fixed wrong MinTime reported by /status. #7182
  * React UI: Fixed multiselect legend on OSX. #6880
  * Remote Write: Fixed blocked resharding edge case. #7122
  * Remote Write: Fixed remote write not updating on relabel configs change. #7073
- Changes from 2.17.2
  + Bug fixes
  * Federation: Register federation metrics #7081
  * PromQL: Fix panic in parser error handling #7132
  * Rules: Fix reloads hanging when deleting a rule group that is being evaluated #7138
  * TSDB: Fix a memory leak when prometheus starts with an empty TSDB WAL #7135
  * TSDB: Make isolation more robust to panics in web handlers #7129 #7136
- Changes from 2.17.1
  + Bug fixes
  * TSDB: Fix query performance regression that increased memory and CPU usage #7051
- Changes from 2.17.0
  + Features
  * TSDB: Support isolation #6841
  * This release implements isolation in TSDB. API queries and recording rules are
    guaranteed to only see full scrapes and full recording rules. This comes with a
    certain overhead in resource usage. Depending on the situation, there might be
    some increase in memory usage, CPU usage, or query latency.
  + Enhancements
  * PromQL: Allow more keywords as metric names #6933
  * React UI: Add normalization of localhost URLs in targets page #6794
  * Remote read: Read from remote storage concurrently #6770
  * Rules: Mark deleted rule series as stale after a reload #6745
  * Scrape: Log scrape append failures as debug rather than warn #6852
  * TSDB: Improve query performance for queries that partially hit the head #6676
  * Consul SD: Expose service health as meta label #5313
  * EC2 SD: Expose EC2 instance lifecycle as meta label #6914
  * Kubernetes SD: Expose service type as meta label for K8s service role #6684
  * Kubernetes SD: Expose label_selector and field_selector #6807
  * Openstack SD: Expose hypervisor id as meta label #6962
  + Bug fixes
  * PromQL: Do not escape HTML-like chars in query log #6834 #6795
  * React UI: Fix data table matrix values #6896
  * React UI: Fix new targets page not loading when using non-ASCII characters #6892
  * Remote read: Fix duplication of metrics read from remote storage with external labels #6967 #7018
  * Remote write: Register WAL watcher and live reader metrics for all remotes, not just the first one #6998
  * Scrape: Prevent removal of metric names upon relabeling #6891
  * Scrape: Fix 'superfluous response.WriteHeader call' errors when scrape fails under some circonstances #6986
  * Scrape: Fix crash when reloads are separated by two scrape intervals #7011
- Changes from 2.16.0
  + Features
  * React UI: Support local timezone on /graph #6692
  * PromQL: add absent_over_time query function #6490
  * Adding optional logging of queries to their own file #6520
  + Enhancements
  * React UI: Add support for rules page and "Xs ago" duration displays #6503
  * React UI: alerts page, replace filtering togglers tabs with checkboxes #6543
  * TSDB: Export metric for WAL write errors #6647
  * TSDB: Improve query performance for queries that only touch the most recent 2h of data. #6651
  * PromQL: Refactoring in parser errors to improve error messages #6634
  * PromQL: Support trailing commas in grouping opts #6480
  * Scrape: Reduce memory usage on reloads by reusing scrape cache #6670
  * Scrape: Add metrics to track bytes and entries in the metadata cache #6675
  * promtool: Add support for line-column numbers for invalid rules output #6533
  * Avoid restarting rule groups when it is unnecessary #6450
  + Bug fixes
  * React UI: Send cookies on fetch() on older browsers #6553
  * React UI: adopt grafana flot fix for stacked graphs #6603
  * React UI: broken graph page browser history so that back button works as expected #6659
  * TSDB: ensure compactionsSkipped metric is registered, and log proper error if one is returned from head.Init #6616
  * TSDB: return an error on ingesting series with duplicate labels #6664
  * PromQL: Fix unary operator precedence #6579
  * PromQL: Respect query.timeout even when we reach query.max-concurrency #6712
  * PromQL: Fix string and parentheses handling in engine, which affected React UI #6612
  * PromQL: Remove output labels returned by absent() if they are produced by multiple identical label matchers #6493
  * Scrape: Validate that OpenMetrics input ends with `# EOF` #6505
  * Remote read: return the correct error if configs can't be marshal'd to JSON #6622
  * Remote write: Make remote client `Store` use passed context, which can affect shutdown timing #6673
  * Remote write: Improve sharding calculation in cases where we would always be consistently behind by tracking pendingSamples #6511
  * Ensure prometheus_rule_group metrics are deleted when a rule group is removed #6693
- Changes from 2.15.2
  + Bug fixes
  * TSDB: Fixed support for TSDB blocks built with Prometheus before 2.1.0. #6564
  * TSDB: Fixed block compaction issues on Windows. #6547
- Changes from 2.15.1
  + Bug fixes
  * TSDB: Fixed race on concurrent queries against same data. #6512
- Changes from 2.15.0
  + Features
  * API: Added new endpoint for exposing per metric metadata `/metadata`. #6420 #6442
  + Changes
  * Discovery: Removed `prometheus_sd_kubernetes_cache_*` metrics. Additionally `prometheus_sd_kubernetes_workqueue_latency_seconds` and `prometheus_sd_kubernetes_workqueue_work_duration_seconds` metrics now show correct values in seconds. #6393
  * Remote write: Changed `query` label on `prometheus_remote_storage_*` metrics to `remote_name` and `url`. #6043
  + Enhancements
  * TSDB: Significantly reduced memory footprint of loaded TSDB blocks. #6418 #6461
  * TSDB: Significantly optimized what we buffer during compaction which should result in lower memory footprint during compaction. #6422 #6452 #6468 #6475
  * TSDB: Improve replay latency. #6230
  * TSDB: WAL size is now used for size based retention calculation. #5886
  * Remote read: Added query grouping and range hints to the remote read request #6401
  * Remote write: Added `prometheus_remote_storage_sent_bytes_total` counter per queue. #6344
  * promql: Improved PromQL parser performance. #6356
  * React UI: Implemented missing pages like `/targets` #6276, TSDB status page #6281 #6267 and many other fixes and performance improvements.
  * promql: Prometheus now accepts spaces between time range and square bracket. e.g `[ 5m]` #6065
  + Bug fixes
  * Config: Fixed alertmanager configuration to not miss targets when configurations are similar. #6455
  * Remote write: Value of `prometheus_remote_storage_shards_desired` gauge shows raw value of desired shards and it's updated correctly. #6378
  * Rules: Prometheus now fails the evaluation of rules and alerts where metric results collide with labels specified in `labels` field. #6469
  * API: Targets Metadata API `/targets/metadata` now accepts empty `match_targets` parameter as in the spec. #6303
- Changes from 2.14.0
  + Features
  * API: `/api/v1/status/runtimeinfo` and `/api/v1/status/buildinfo` endpoints added for use by the React UI. #6243
  * React UI: implement the new experimental React based UI. #5694 and many more
  * Can be found by under `/new`.
  * Not all pages are implemented yet.
  * Status: Cardinality statistics added to the Runtime & Build Information page. #6125
  + Enhancements
  * Remote write: fix delays in remote write after a compaction. #6021
  * UI: Alerts can be filtered by state. #5758
  + Bug fixes
  * Ensure warnings from the API are escaped. #6279
  * API: lifecycle endpoints return 403 when not enabled. #6057
  * Build: Fix Solaris build. #6149
  * Promtool: Remove false duplicate rule warnings when checking rule files with alerts. #6270
  * Remote write: restore use of deduplicating logger in remote write. #6113
  * Remote write: do not reshard when unable to send samples. #6111
  * Service discovery: errors are no longer logged on context cancellation. #6116, #6133
  * UI: handle null response from API properly. #6071
- Changes from 2.13.1
  + Bug fixes
  * Fix panic in ARM builds of Prometheus. #6110
  * promql: fix potential panic in the query logger. #6094
  * Multiple errors of http: superfluous response.WriteHeader call in the logs. #6145
- Changes from 2.13.0
  + Enhancements
  * Metrics: renamed prometheus_sd_configs_failed_total to prometheus_sd_failed_configs and changed to Gauge #5254
  * Include the tsdb tool in builds. #6089
  * Service discovery: add new node address types for kubernetes. #5902
  * UI: show warnings if query have returned some warnings. #5964
  * Remote write: reduce memory usage of the series cache. #5849
  * Remote read: use remote read streaming to reduce memory usage. #5703
  * Metrics: added metrics for remote write max/min/desired shards to queue manager. #5787
  * Promtool: show the warnings during label query. #5924
  * Promtool: improve error messages when parsing bad rules. #5965
  * Promtool: more promlint rules. #5515
  + Bug fixes
  * UI: Fix a Stored DOM XSS vulnerability with query history [CVE-2019-10215](http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-10215). #6098
  * Promtool: fix recording inconsistency due to duplicate labels. #6026
  * UI: fixes service-discovery view when accessed from unhealthy targets. #5915
  * Metrics format: OpenMetrics parser crashes on short input. #5939
  * UI: avoid truncated Y-axis values. #6014
- Changes from 2.12.0
  + Features
  * Track currently active PromQL queries in a log file. #5794
  * Enable and provide binaries for `mips64` / `mips64le` architectures. #5792
  + Enhancements
  * Improve responsiveness of targets web UI and API endpoint. #5740
  * Improve remote write desired shards calculation. #5763
  * Flush TSDB pages more precisely. tsdb#660
  * Add `prometheus_tsdb_retention_limit_bytes` metric. tsdb#667
  * Add logging during TSDB WAL replay on startup. tsdb#662
  * Improve TSDB memory usage. tsdb#653, tsdb#643, tsdb#654, tsdb#642, tsdb#627
  + Bug fixes
  * Check for duplicate label names in remote read. #5829
  * Mark deleted rules' series as stale on next evaluation. #5759
  * Fix JavaScript error when showing warning about out-of-sync server time. #5833
  * Fix `promtool test rules` panic when providing empty `exp_labels`. #5774
  * Only check last directory when discovering checkpoint number. #5756
  * Fix error propagation in WAL watcher helper functions. #5741
  * Correctly handle empty labels from alert templates. #5845
* Wed May 13 2020 jcavalheiro@suse.com
- Update Uyuni/SUSE Manager service discovery patch
  + Modified 0003-Add-Uyuni-service-discovery.patch:
  + Adapt service discovery to the new Uyuni API endpoints
  + Modified spec file: force golang 1.12 to fix build issues in SLE15SP2
* Mon Jan 27 2020 witold.bedyk@suse.com
- Update to Prometheus 2.11.2
* Mon Nov 25 2019 jcavalheiro@suse.com
- Patch macros on spec file to support builds on SLE 12
* Thu Nov 21 2019 jan.fajerski@suse.com
- Remove prometheus.firewall.xml source file
* Wed Nov 20 2019 mrostecki@opensuse.org
- Remove firewalld files. They are installed in the main firewalld
  package.
* Wed Nov 20 2019 jcavalheiro@suse.com
- Update Uyuni/SUSE Manager service discovery patch
  + Modified 0003-Add-Uyuni-service-discovery.patch
  + Fixes crashes when systems have no FQDN
  + Adds Parallel calls to Uyuni API, meaningful performance increase
  + Adds Support for system group labels
* Mon Sep 23 2019 mrostecki@opensuse.org
- Do not install the firewalld config file on Tumbleweed (on
  versions newer than Leap 15.1). It's installed in the main
  firewalld package.
* Fri Aug 16 2019 jan.fajerski@suse.com
- remove 0004-prometheus-buildmode-pie.patch
  + this patch produces binaries that crash immediately
- add -v to promu build command for better build debugging
- reorder some %%install tasks
* Fri Aug  2 2019 jan.fajerski@suse.com
- Add network-online (Wants and After) dependency to systemd unit bsc#1143913
* Wed Jul 31 2019 asn@cryptomilk.org
- Build with PIE
  + Added 0004-prometheus-buildmode-pie.patch
* Wed Jul 31 2019 asn@cryptomilk.org
- Only package required files (reduces rpm size by 4 MB)
- Add sysconfig file
- Add firewall config file
- Use variables for defining user and group
* Thu Jul 25 2019 jcavalheiro@suse.com
- Add support for Uyuni/SUSE Manager service discovery
  + Added 0003-Add-Uyuni-service-discovery.patch
* Thu Jul 18 2019 simon.crute@grafana.com
- readded _service file removed in error.
- Update to 2.11.1
  + Bug Fix:
  * Fix potential panic when prometheus is watching multiple zookeeper paths.
- Update to 2.11.0
  + Bug Fix:
  * resolve race condition in maxGauge.
  * Fix ZooKeeper connection leak.
  * Improved atomicity of .tmp block replacement during compaction for usual case.
  * Fix "unknown series references" after clean shutdown.
  * Re-calculate block size when calling block.Delete.
  * Fix unsafe snapshots with head block.
  * prometheus_tsdb_compactions_failed_total is now incremented on any compaction failure.
  + Changes:
  * Remove max_retries from queue_config (it has been unused since rewriting remote-write to utilize the write-ahead-log)
  * The meta file BlockStats no longer holds size information. This is now dynamically calculated and kept in memory. It also includes the meta file size which was not included before
  * Renamed metric from prometheus_tsdb_wal_reader_corruption_errors to prometheus_tsdb_wal_reader_corruption_errors_total
  + Features:
  * Add option to use Alertmanager API v2.
  * Added humanizePercentage function for templates.
  * Include InitContainers in Kubernetes Service Discovery.
  * Provide option to compress WAL records using Snappy.
  + Enhancements:
  * Create new clean segment when starting the WAL.
  * Reduce allocations in PromQL aggregations.
  * Add storage warnings to LabelValues and LabelNames API results.
  * Add prometheus_http_requests_total metric.
  * Enable openbsd/arm build.
  * Remote-write allocation improvements.
  * Query performance improvement: Efficient iteration and search in HashForLabels and HashWithoutLabels.
  * Allow injection of arbitrary headers in promtool.
  * Allow passing external_labels in alert unit tests groups.
  * Allows globs for rules when unit testing.
  * Improved postings intersection matching.
  * Reduced disk usage for WAL for small setups.
  * Optimize queries using regexp for set lookups.
* Thu Jul  4 2019 simon.crute@grafana.com
- rebase patch002-Default-settings.patch
- Update to 2.10.0:
  + Bug Fixes:
  * TSDB: Don't panic when running out of disk space and recover nicely from the condition
  * TSDB: Correctly handle empty labels.
  * TSDB: Don't crash on an unknown tombstone reference.
  * Storage/remote: Remove queue-manager specific metrics if queue no longer exists.
  * PromQL: Correctly display {__name__="a"}.
  * Discovery/kubernetes: Use service rather than ingress as the name for the service workqueue.
  * Discovery/azure: Don't panic on a VM with a public IP.
  * Web: Fixed Content-Type for js and css instead of using /etc/mime.types.
  * API: Encode alert values as string to correctly represent Inf/NaN.
  + Features:
  * Template expansion: Make external labels available as $externalLabels in alert and console template expansion.
  * TSDB: Add prometheus_tsdb_wal_segment_current metric for the WAL segment index that TSDB is currently writing to. tsdb
  * Scrape: Add scrape_series_added per-scrape metric. #5546
  + Enhancements
  * Discovery/kubernetes: Add labels __meta_kubernetes_endpoint_node_name and __meta_kubernetes_endpoint_hostname.
  * Discovery/azure: Add label __meta_azure_machine_public_ip.
  * TSDB: Simplify mergedPostings.Seek, resulting in better performance if there are many posting lists. tsdb
  * Log filesystem type on startup.
  * Cmd/promtool: Use POST requests for Query and QueryRange. client_golang
  * Web: Sort alerts by group name.
  * Console templates: Add convenience variables $rawParams, $params, $path.
- Upadte to 2.9.2
  + Bug Fixes:
  * Make sure subquery range is taken into account for selection
  * Exhaust every request body before closing it
  * Cmd/promtool: return errors from rule evaluations
  * Remote Storage: string interner should not panic in release
  * Fix memory allocation regression in mergedPostings.Seek tsdb
- Update to 2.9.1
  + Bug Fixes:
  * Discovery/kubernetes: fix missing label sanitization
  * Remote_write: Prevent reshard concurrent with calling stop
- Update to 2.9.0
  + Feature:
  * Add honor_timestamps scrape option.
  + Enhancements:
  * Update Consul to support catalog.ServiceMultipleTags.
  * Discovery/kubernetes: add present labels for labels/annotations.
  * OpenStack SD: Add ProjectID and UserID meta labels.
  * Add GODEBUG and retention to the runtime page.
  * Add support for POSTing to /series endpoint.
  * Support PUT methods for Lifecycle and Admin APIs.
  * Scrape: Add global jitter for HA server.
  * Check for cancellation on every step of a range evaluation.
  * String interning for labels & values in the remote_write path.
  * Don't lose the scrape cache on a failed scrape.
  * Reload cert files from disk automatically. common
  * Use fixed length millisecond timestamp format for logs. common
  * Performance improvements for postings.
  Bug Fixes:
  * Remote Write: fix checkpoint reading.
  * Check if label value is valid when unmarshaling external labels from YAML.
  * Promparse: sort all labels when parsing.
  * Reload rules: copy state on both name and labels.
  * Exponentation operator to drop metric name in result of operation.
  * Config: resolve more file paths.
  * Promtool: resolve relative paths in alert test files.
  * Set TLSHandshakeTimeout in HTTP transport. common
  * Use fsync to be more resilient to machine crashes.
  * Keep series that are still in WAL in checkpoints.
- Update to 2.8.1
  + Bug Fixes
  * Display the job labels in /targets which was removed accidentally
- Update to 2.8.0
  + Change:
  * This release uses Write-Ahead Logging (WAL) for the remote_write API. This currently causes a slight increase in memory usage, which will be addressed in future releases.
  * Default time retention is used only when no size based retention is specified. These are flags where time retention is specified by the flag --storage.tsdb.retention and size retention by --storage.tsdb.retention.size.
  * prometheus_tsdb_storage_blocks_bytes_total is now prometheus_tsdb_storage_blocks_bytes.
  + Feature:
  * (EXPERIMENTAL) Time overlapping blocks are now allowed; vertical compaction and vertical query merge. It is an optional feature which is controlled by the --storage.tsdb.allow-overlapping-blocks flag, disabled by default.
  + Enhancements:
  * Use the WAL for remote_write API.
  * Query performance improvements.
  * UI enhancements with upgrade to Bootstrap 4.
  * Reduce time that Alertmanagers are in flux when reloaded.
  * Limit number of metrics displayed on UI to 10000.
  * (1) Remember All/Unhealthy choice on target-overview when reloading page. (2) Resize text-input area on Graph page on mouseclick.
  * In histogram_quantile merge buckets with equivalent le values.
  * Show list of offending labels in the error message in many-to-many scenarios.
  * Show Storage Retention criteria in effect on /status page.
  + Bug Fixes:
    + Fix sorting of rule groups.
    + Fix support for password_file and bearer_token_file in Kubernetes SD.
    + Scrape: catch errors when creating HTTP clients
    + Adds new metrics:
    prometheus_target_scrape_pools_total
    prometheus_target_scrape_pools_failed_total
    prometheus_target_scrape_pool_reloads_total
    prometheus_target_scrape_pool_reloads_failed_total
    + Fix panic when aggregator param is not a literal.
* Fri Feb 22 2019 jan.fajerski@suse.com
- fix spec file: actually ship promtool
* Fri Feb  8 2019 jan.fajerski@suse.com
- Update to 2.7.1:
  + Bug Fixes:
  * Fix a Stored DOM XSS vulnerability with query history (boo#1124610)
  * prometheus_rule_group_last_duration_seconds now reports seconds instead of nanoseconds
  * Make sure the targets are consistently sorted in the targets page
- Update to 2.7.0:
  + cli flag depreacted: storage.tsdb.retention use storage.tsdb.retention.time
    instead; depreacted flag will be removed in 3.0
  + Features:
  * Add subqueries to PromQL
  * Add support for disk size based retention. Note that we don't
    consider the WAL size which could be significant and the time
    based retention policy also applies (experimental)
  * Add CORS origin flag
  + Bug Fixes:
  * Don't depend on given order when comparing samples in alert unit testing
  * Make sure the retention period doesn't overflow
  * Don't generate blocks with no samples
- Update to 2.6.0:
  + Remove default flags from the container's entrypoint, run Prometheus from
    /etc/prometheus and symlink the storage directory to /etc/prometheus/data
  + Promtool: Remove the update command
  + Features:
  * Add JSON log format via the --log.format flag
  * API: Add /api/v1/labels endpoint to get all label names
  * Web: Allow setting the page's title via the --web.ui-title flag
  + Enhancements:
  * Add prometheus_tsdb_lowest_timestamp_seconds, prometheus_tsdb_head_min_time_seconds
    and prometheus_tsdb_head_max_time_seconds metrics
  * Add rule_group_last_evaluation_timestamp_seconds metric
  * Add prometheus_template_text_expansion_failures_total and prometheus_template_text_expansions_total metrics
  * Set consistent User-Agent header in outgoing requests
  * Azure SD: Error out at load time when authentication parameters are missing
  * EC2 SD: Add the machine's private DNS name to the discovery metadata
  * EC2 SD: Add the operating system's platform to the discovery metadata
  * Kubernetes SD: Add the pod's phase to the discovery metadata
  * Kubernetes SD: Log Kubernetes messages
  * Promtool: Collect CPU and trace profiles
  * Promtool: Support writing output as JSON
  * Remote Read: Return available data if remote read fails partially
  * Remote Write: Improve queue performance
  * Remote Write: Add min_shards parameter to set the minimum number of shards
  * TSDB: Improve WAL reading
  * TSDB: Memory improvements
  * Web: Log stack traces on panic
  * Web UI: Add copy to clipboard button for configuration
  * Web UI: Support console queries at specific times
  * Web UI: group targets by job then instance
  + Bug Fixes:
  * Deduplicate handler labels for HTTP metrics
  * Fix leaked queriers causing shutdowns to hang
  * Fix configuration loading panics on nil pointer slice elements
  * API: Correctly skip mismatching targets on /api/v1/targets/metadata
  * API: Better rounding for incoming query timestamps
  * Discovery: Remove all targets when the scrape configuration gets empty
  * PromQL: Fix a goroutine leak in the lexer/parser
  * Scrape: Fix deadlock in the scrape's manager
  * Scrape: Scrape targets at fixed intervals even after Prometheus restarts
  * TSDB: Support restored snapshots including the head properly
  * TSDB: Repair WAL when the last record in a segment is torn
- Update to 2.5.0
  + Group targets by scrape config instead of job name
  + Marathon SD: Various changes to adapt to Marathon 1.5+
  + Discovery: Split prometheus_sd_discovered_targets metric by scrape and
    notify (Alertmanager SD) as well as by section in the respective configuration
  + Enhancements:
  * Support s390x platform for Linux
  * API: Add prometheus_api_remote_read_queries metric tracking currently
    executed or waiting remote read API requests
  * Remote Read: Add prometheus_remote_storage_remote_read_queries metric
    tracking currently in-flight remote read queries
  * Remote Read: Reduced memory usage
  * Discovery: Add prometheus_sd_discovered_targets,
    prometheus_sd_received_updates_total, prometheus_sd_updates_delayed_total,
    and prometheus_sd_updates_total metrics for discovery subsystem
  * Discovery: Improve performance of previously slow updates of changes of targets
  * Kubernetes SD: Add extended metrics
  * OpenStack SD: Support discovering instances from all projects
  * OpenStack SD: Discover all interfaces
  * OpenStack SD: Support tls_config for the used HTTP client
  * Triton SD: Add ability to filter triton_sd targets by pre-defined groups
  * Web UI: Avoid browser spell-checking in expression field
  * Web UI: Add scrape duration and last evaluation time in targets and rules pages
  * Web UI: Improve rule view by wrapping lines
  * Rules: Error out at load time for invalid templates, rather than at evaluation time
  + Bug Fixes:
  * Change max/min over_time to handle NaNs properly
  * Check label name for count_values PromQL function
  * Ensure that vectors and matrices do not contain identical label-sets
- Update to 2.4.3
  + Bug Fixes:
    [BUGFIX] Fix panic when using custom EC2 API for SD #4672
    [BUGFIX] Fix panic when Zookeeper SD cannot connect to servers #4669
    [BUGFIX] Make the skip_head an optional parameter for snapshot API #4674
- Update to 2.4.2
  + Bug Fixes:
    [BUGFIX] Handle WAL corruptions properly prometheus/tsdb#389
    [BUGFIX] Handle WAL migrations correctly on Windows prometheus/tsdb#392
- Update to 2.4.1
  + New TSDB metrics
  + Bug Fixes:
  Render UI correctly for Windows
- Update to 2.4.0
  + The WAL implementation has been re-written so the storage is not forward
    compatible. Prometheus 2.3 storage will work on 2.4 but not vice-versa
  + Reduce remote write default retries
  + Remove /heap endpoint
  + Features:
  * Persist alert 'for' state across restarts
  * Add API providing per target metric metadata
  * Add API providing recording and alerting rules
  + Enhancements:
  * Brand new WAL implementation for TSDB. Forwards incompatible with previous WAL.
  * Show rule evaluation errors in UI
  * Throttle resends of alerts to Alertmanager
  * Send EndsAt along with the alert to Alertmanager
  * Limit the samples returned by remote read endpoint
  * Limit the data read in through remote read
  * Coalesce identical SD configuations
  * promtool: Add new commands for debugging and querying
  * Update console examples for node_exporter v0.16.0
  * Optimize PromQL aggregations
  * Remote read: Add Offset to hints
  * consul_sd: Add support for ServiceMeta field
  * ec2_sd: Maintain order of subnet_id label
  * ec2_sd: Add support for custom endpoint to support EC2 compliant APIs
  * ec2_sd: Add instance_owner label
  * azure_sd: Add support for VMSS discovery and multiple environments
  * gce_sd: Add instance_id label
  * Forbid rule-abiding robots from indexing
  * Log virtual memory limits on startup
  + Bug Fixes:
  * Wait for service discovery to stop before exiting
  * Render SD configs properly
  * Only add LookbackDelta to vector selectors
  * ec2_sd: Handle panic-ing nil pointer
  * consul_sd: Stop leaking connections
  * Use templated labels also to identify alerts
  * Reduce floating point errors in stddev and related functions
  * Log errors while encoding responses
- Update to 2.3.2
  + Bug Fixes:
  * Fix various tsdb bugs
  * Reorder startup and shutdown to prevent panics.
  * Exit with non-zero code on error
  * discovery/kubernetes/ingress: fix scheme discovery
  * Fix race in zookeeper sd
  * Better timeout handling in promql
  * Propogate errors when selecting series from the tsdb
- Update to 2.3.1
  + Bug Fixes:
  * Avoid infinite loop on duplicate NaN values.
  * Fix nil pointer deference when using various API endpoints
  * config: set target group source index during unmarshalling
  * discovery/file: fix logging
  * kubernetes_sd: fix namespace filtering
  * web: restore old path prefix behavior
  * web: remove security headers added in 2.3.0
- Update to 2.3.0
  + marathon_sd: use auth_token and auth_token_file for token-based authentication
    instead of bearer_token and bearer_token_file respectively
  + Metric names for HTTP server metrics changed
  + Features:
  * Add query commands to promtool
  * Add security headers to HTTP server responses
  * Pass query hints via remote read API
  * Basic auth passwords can now be configured via file across all configuration
  + Enhancements:
  * Optimise PromQL and API serialization for memory usage and allocations
  * Limit number of dropped targets in web UI
  * Consul and EC2 service discovery allow using server-side filtering for performance improvement
  * Add advanced filtering configuration to EC2 service discovery
  * marathon_sd: adds support for basic and bearer authentication, plus all
    other common HTTP client options (TLS config, proxy URL, etc.)
  * Provide machine type metadata and labels in GCE service discovery
  * Add pod controller kind and name to Kubernetes service discovery data
  * Move TSDB to flock-based log file that works with Docker containers
  + Bug Fixes:
  * Properly propagate storage errors in PromQL
  * Fix path prefix for web pages
  * Fix goroutine leak in Consul service discovery
  * Fix races in scrape manager
  * Fix OOM for very large k in PromQL topk() queries
  * Make remote write more resilient to unavailable receivers
  * Make remote write shutdown cleanly
  * Don't leak files on errors in TSDB's tombstone cleanup
  * Unary minus expressions now removes the metric name from results
  * Fix bug that lead to wrong amount of samples considered for time range expressions
- Update to 2.2.1
  + Bug Fixes:
  * Fix data loss in TSDB on compaction
  * Correctly stop timer in remote-write path
  * Fix deadlock triggered by loading targets page
  * Fix incorrect buffering of samples on range selection queries
  * Handle large index files on windows properly
- Update to 2.2.0
  + This release introduces improvements to the storage format and fixes a
    regression introduced in 2.1. As a result Prometheus servers upgraded
    to 2.2 cannot be downgraded to a lower version anymore!
  + Rename file SD mtime metric
  + Send target update on empty pod IP in Kubernetes SD
  + Features:
  * Add API endpoint for flags.
  * Add API endpoint for dropped targets.
  * Display annotations on alerts page.
  * Add option to skip head data when taking snapshots
  + Enhancements:
  * Federation performance improvement.
  * Read bearer token file on every scrape.
  * Improve typeahead on /graph page.
  * Change rule file formatting.
  * Set consul server default to localhost:8500.
  * Add dropped Alertmanagers to API info endpoint.
  * Add OS type meta label to Azure SD.
  * Validate required fields in SD configuration.
  + Bug Fixes:
  * Prevent stack overflow on deep recursion in TSDB.
  * Correctly read offsets in index files that are greater than 4GB.
  * Fix scraping behavior for empty labels.
  * Drop metric name for bool modifier.
  * Fix races in discovery.
  * Fix Kubernetes endpoints SD for empty subsets.
  * Throttle updates from SD providers, which caused increased CPU usage and allocations.
  * Fix TSDB block reload issue.
  * Fix PromQL printing of empty without().
  * Don't reset FiredAt for inactive alerts.
  * Fix erroneous file version changes and repair existing data.
- remove pr-3174.patch, has been fixed in https://github.com/prometheus/prometheus/pull/3517
* Wed Mar 14 2018 jan.fajerski@suse.com
- spec: fix directory for fdupes
* Thu Jan 25 2018 kkaempf@suse.com
- Update to 2.1.0:
  + Features:
  * New Service Discovery UI showing labels before and after relabelling.
  * New Admin APIs added to v1 to delete, snapshot and remove tombstones.
  + Enhancements:
  * The graph UI autcomplete now includes your previous queries.
  * Federation is now much faster for large numbers of series.
  * Added new metrics to measure rule timings.
  * Rule evaluation times added to the rules UI.
  * Added metrics to measure modified time of file SD files.
  * Kubernetes SD now includes POD UID in discovery metadata.
  * The Query APIs now return optional stats on query execution times.
  * The index now no longer has the 4GiB size limit and is also smaller.
  + Bug Fixes:
  * Remote read read_recent option is now false by default.
  * Pass the right configuration to each Alertmanager (AM) when using
    multiple AM configs.
  * Fix not-matchers not selecting series with labels unset.
  * tsdb: Fix occasional panic in head block.
  * tsdb: Close files before deletion to fix retention issues on Windows
    and NFS.
  * tsdb: Cleanup and do not retry failing compactions.
  * tsdb: Close WAL while shutting down.
* Thu Nov  9 2017 tserong@suse.com
- Update to final v2.0.0 release (bsc#1067341):
  + Compared to version 1.x, this release includes a completely rewritten
    storage engine, huge performance improvements, but also many backwards
    incompatible changes.  For more information, read the announcement blog
    post and migration guide:
  - https://prometheus.io/blog/2017/11/08/announcing-prometheus-2-0/
  - https://prometheus.io/docs/prometheus/2.0/migration/
  + Changes:
  * Completely rewritten storage layer, with WAL.  This is not backwards
    compatible with 1.x storage,  and many flags have changed/disappeared.
  * New staleness behavior. Series now marked stale after target scrapes
    no longer return them, and soon after targets disappear from service
    discovery.
  * Rules files use YAML syntax now.  Conversion tool added to promtool.
  * Removed count_scalar, drop_common_labels functions and keep_common
    modifier from PromQL.
  * Rewritten exposition format parser with much higher performance.  The
    Protobuf exposition format is no longer supported.
  * Example console templates updated for new storage and metrics names.
    Examples other than node exporter and Prometheus removed.
  * Admin and lifecycle APIs now disabled by default, can be reenabled via
    flags
  * Flags switched to using Kingpin, all flags are now --flagname rather
    than -flagname.
  + Features:
  * Remote read can be configured to not read data which is available
    locally.  This is enabled by default.
  * Rules can be grouped now.  Rules within a rule group are executed
    sequentially.
  * Added experimental GRPC apis
  * Add timestamp() function to PromQL.
  + Enhancements:
  * Remove remote read from the query path if no remote storage is
    configured.
  * Bump Consul HTTP client timeout to not match the Consul SD watch
    timeout.
  * Go-conntrack added to provide HTTP connection metrics.
  + Bug Fixes:
  * Fix connection leak in Consul SD.
* Tue Nov  7 2017 tserong@suse.com
- Update to v2.0.0-rc.3 (bsc#1067030):
  + Enhancements:
  * Remove remote read from the query path if no remote storage
    is configured.
  * Bump Consul HTTP client timeout to not match the Consul SD
    watch timeout.
  * Bump up a too small max block duration to the min block
    duration instead of returning an error.
  + Bug Fixes:
  * Avoid needless padding of 4 zero bytes in index files.
  * Delete old blocks during reload (necessary on MS Windows).
  * Fix regression of alert rules state loss on config reload.
  * Serialize background WAL operations to avoid data races.
  + This also contains bugfixes and remote-storage features from
    the 1.8 branch.
* Fri Oct 27 2017 tserong@suse.com
- Update to v2.0.0-rc.2 (bsc#1065377):
  + Enhancements:
  * Handle WAL segments with corrupted header gracefully
  * Stabilize memory usage during WAL replay
  + Changes:
  * Prefix all storage metrics with prometheus_
  + Bug Fixes:
  * Correctly handle label removal in remote read
  * Fix chunk misalignment causing out-of-order samples
  * Fix connection leak in Consul SD
  * Handle invalid chunk dereferences gracefully
  * Prevent potential deadlock during failing querier construction
* Thu Oct 19 2017 tserong@suse.com
- Update to v2.0.0-rc.1:
  + Features/Enhancements:
  * Added a warning for time-drift between the browser and the
    prometheus-server.
  * Much faster WAL read-back on restart.
  + Bug Fixes:
  * Fixed Remote-read to not drop the first series.
  * Validate recording-rule names.
  * Fix several races.
  * Only close blocks if there are no iterators accessing it.
- Refresh 0002-Default-settings.patch
* Wed Oct 11 2017 tserong@suse.com
- Update to v2.0.0-rc.0:
  + Numerous changes to the new storage layer, the main changes being:
  * Remove `count_scalar`, `keep_common` and `drop_common_labels` functions
  * Breaking change in the index format for better consistency
  * Fix panic due garbage collected mmap'ed strings
  * Fix broken snapshots and admin APIs
  * Send HTTP Accept header when scraping
  * Use the WAL flush interval passed instead of the hardcoded value
  + This release requires a clean storage directory and is not compatible
    with files created by previous beta releases
- Refresh 0002-Default-settings.patch
* Sun Sep 24 2017 tserong@suse.com
- Fix loopback address for REST API gateway (bsc#1059462)
  + Added pr-3174.patch
* Fri Sep 22 2017 tserong@suse.com
- Update to v2.0.0-beta.5:
  + Bug Fixes:
  * Remove deadlock on startup when restoring WAL
  * Fix semantical races resulting in invalid persisted files
  * Correctly read back WAL in certain edge cases
  * Prevent crashes caused by changing metric representations in target's
    /metrics
  + Enhancements:
  * Overall memory usage reduction
  * Serve debugging endpoints while TSDB is loading
  * Healthy endpoint correctly reflects liveness during startup
  * Switch to consistent usage of go-kit/log
  + This release may have issues with files written by previous beta releases
- Refresh 0002-Default-settings.patch to apply cleanly again
* Mon Sep 18 2017 tserong@suse.com
- Update to v2.0.0-beta.4:
  + Numerous changes to the new storage layer, the main changes being:
  * Single, compacted write ahead log
  * Single in-memory block with garbage collection
  * Improve compression of index files
  * Cache series dropped via metric_relabel_configs
  * Pool byte buffers for scraping
  + Overall the changes achieve a baseline reduction in memory consumption
    and reduce peak memory usage by 30-40%% compared to 2.0.0-beta.2
  + This release requires a clean storage directory and is not compatible
    with files created by previous beta releases
* Tue Aug 22 2017 tserong@suse.com
- Update to v2.0.0-beta.2
  + vendor: update prometheus/tsdb (Fix panic caused by 0 division)
* Wed Aug 16 2017 tserong@suse.com
- Update to v2.0.0-beta.1
  + Includes a new storage layer, which reduces bottlenecks and shows
    considerable performance improvements, but does not work with old v1
    storage data.
- Refresh 0002-Default-settings.patch to apply cleanly again
* Tue May  9 2017 tserong@suse.com
- Add systemd unit file and default config (/etc/prometheus/prometheus.yml)
- Run as unprivileged "prometheus" user
- Default to /etc/prometheus for config and /var/lib/prometheus for metrics
  + Added 0002-Default-settings.patch
* Wed Apr 26 2017 tserong@suse.com
- Add BuildRequires: glibc-devel-static to fix aarch64 build
* Wed Mar 29 2017 moio@suse.com
- Initial version
